<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Admission;
use Illuminate\Http\Request;

class AdmissionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.admission.index');
    }

    /**
     * Get the admissions
     */
    public function getAdmissions()
    {
        $admissions = Admission::latest()->get();

        return response()->json($admissions);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.admission.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $admission = new Admission();

        $admission->title_en = $request->title_en;
        $admission->title_kh = $request->title_kh;
        $admission->description = $request->description;

        $admission->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Admission created successfully.'
        );

        return redirect()->route('study.admissions')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $admission = Admission::find($id);

        return view('backend.admission.edit', compact('admission'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $admission = Admission::find($id);

        $admission->title_en = $request->title_en;
        $admission->title_kh = $request->title_kh;
        $admission->description = $request->description;

        $admission->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Admission updated successfully.'
        );

        return redirect()->route('study.admissions')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $admission = Admission::find($request->id);

        $admission->activation = $request->activation;
        $admission->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Admission status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $admission = Admission::find($id);

        $admission->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Admission deleted successfully.'
        );

        return response()->json($notification);
    }
}
