<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Career;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class CareerController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.career.index');
    }

    /**
     * Get the careers
     */
    public function getCareers()
    {
        $careers = Career::latest()->get();

        return response()->json($careers);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.career.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $career = new Career();

        $career->title_en = $request->title_en;
        $career->title_kh = $request->title_kh;
        $career->position = $request->position;
        $career->company = $request->company;
        $career->website = $request->website;
        $career->email = $request->email;
        $career->tel = $request->tel;
        $career->number = $request->number;
        $career->location = $request->location;
        $career->start_date = date('Y-m-d', strtotime($request->start_date));
        $career->end_date = date('Y-m-d', strtotime($request->end_date));
        $career->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'career-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/career/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $career->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $career->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Career created successfully.'
        );

        return redirect()->route('careers')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $career = Career::find($id);

        return view('backend.career.edit', compact('career'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $career = Career::find($id);

        $career->title_en = $request->title_en;
        $career->title_kh = $request->title_kh;
        $career->position = $request->position;
        $career->company = $request->company;
        $career->website = $request->website;
        $career->email = $request->email;
        $career->tel = $request->tel;
        $career->number = $request->number;
        $career->location = $request->location;
        $career->start_date = date('Y-m-d', strtotime($request->start_date));
        $career->end_date = date('Y-m-d', strtotime($request->end_date));
        $career->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'career-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/career/' . $newFileName);

                // Check and delete existing file
                if ($career->image) {
                    $existingFilePath = public_path('uploads/career/' . $career->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                // Move and rename file to final path
                if (File::exists($tempPath)) {
                    if (File::move($tempPath, $finalPath)) {
                        $career->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $career->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Career updated successfully.'
        );

        return redirect()->route('careers')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $career = Career::find($request->id);

        $career->activation = $request->activation;
        $career->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Career status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $career = Career::find($id);

        $career->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Career deleted successfully.'
        );

        return response()->json($notification);
    }
}
