<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Conference;
use App\Models\ResearchInnovationImage;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class ConferenceController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.conference.index');
    }

    /**
     * Get the conferences
     */
    public function getConferences()
    {
        $conferences = Conference::latest()->get();

        return response()->json($conferences);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.conference.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $conference = new Conference();

        $conference->title_en = $request->title_en;
        $conference->title_kh = $request->title_kh;
        $conference->sub_title_en = $request->sub_title_en;
        $conference->sub_title_kh = $request->sub_title_kh;
        $conference->start_date = date('Y-m-d', strtotime($request->start_date));
        $conference->end_date = date('Y-m-d', strtotime($request->end_date));
        $conference->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'conference-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/conference/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $conference->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $conference->save();

        // Handle multiple image uploads
        if ($request->images) {
            foreach ($request->images as $image) {
                // Ensure each image data is JSON decoded
                $imageData = json_decode($image, true);
                if (isset($imageData['fileNames'])) {
                    foreach ($imageData['fileNames'] as $tempFileName) {
                        $tempPath = public_path('uploads/multiple-temp/' . $tempFileName);

                        // Generate new file name
                        $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                        $newFileName = 'gallery-image-' . date('YmdHi') . '-' . uniqid() . '.' . $extension;
                        $finalPath = public_path('uploads/conference/gallery/' . $newFileName);

                        // Debugging logs
                        Log::info("Temp Path: $tempPath");
                        Log::info("Final Path: $finalPath");

                        // Move and rename file to final path
                        if (File::exists($tempPath)) {
                            if (rename($tempPath, $finalPath)) {
                                Log::info("File moved successfully from $tempPath to $finalPath");
                                ResearchInnovationImage::create([
                                    'conference_id' => $conference->id,
                                    'image' => $newFileName,
                                ]);
                            } else {
                                Log::error("Failed to move file from $tempPath to $finalPath");
                            }
                        } else {
                            Log::error("Temporary file not found: " . $tempPath);
                        }
                    }
                } else {
                    Log::error("File names not found in image data: " . $image);
                }
            }
        }

        $notification = array(
            'status' => 'success',
            'message' => 'Conference created successfully.'
        );

        return redirect()->route('research-innovation.conferences')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $conference = Conference::with('images')->find($id);

        return view('backend.conference.edit', compact('conference'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $conference = Conference::find($id);

        $conference->title_en = $request->title_en;
        $conference->title_kh = $request->title_kh;
        $conference->sub_title_en = $request->sub_title_en;
        $conference->sub_title_kh = $request->sub_title_kh;
        $conference->start_date = date('Y-m-d', strtotime($request->start_date));
        $conference->end_date = date('Y-m-d', strtotime($request->end_date));
        $conference->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'conference-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/conference/' . $newFileName);

                // Check and delete existing file
                if ($conference->image) {
                    $existingFilePath = public_path('uploads/conference/' . $conference->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $conference->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        // Handle multiple image uploads
        if ($request->images) {
            foreach ($request->images as $image) {
                // Ensure each image data is JSON decoded
                $imageData = json_decode($image, true);
                if (isset($imageData['fileNames'])) {
                    foreach ($imageData['fileNames'] as $tempFileName) {
                        $tempPath = public_path('uploads/multiple-temp/' . $tempFileName);

                        // Generate new file name
                        $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                        $newFileName = 'gallery-image-' . date('YmdHi') . '-' . uniqid() . '.' . $extension;
                        $finalPath = public_path('uploads/conference/gallery/' . $newFileName);

                        // Debugging logs
                        Log::info("Temp Path: $tempPath");
                        Log::info("Final Path: $finalPath");

                        // Move and rename file to final path
                        if (File::exists($tempPath)) {
                            if (rename($tempPath, $finalPath)) {
                                Log::info("File moved successfully from $tempPath to $finalPath");
                                ResearchInnovationImage::create([
                                    'conference_id' => $conference->id,
                                    'image' => $newFileName,
                                ]);
                            } else {
                                Log::error("Failed to move file from $tempPath to $finalPath");
                            }
                        } else {
                            Log::error("Temporary file not found: " . $tempPath);
                        }
                    }
                } else {
                    Log::error("File names not found in image data: " . $image);
                }
            }
        }

        $conference->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Conference updated successfully.'
        );

        return redirect()->route('research-innovation.conferences')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $conference = Conference::find($request->id);

        $conference->activation = $request->activation;
        $conference->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Conference status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $conference = Conference::find($id);

        $conference->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Conference deleted successfully.'
        );

        return response()->json($notification);
    }
}
