<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Contact;
use Illuminate\Http\Request;

class ContactController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.contact.index');
    }

    /**
     * Get the contacts
     */
    public function getContacts()
    {
        $contacts = Contact::latest()->get();

        return response()->json($contacts);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.contact.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Check if there is at least one record with activation = 1
        $hasActivatedRecord = Contact::where('activation', 1)->exists();

        // Set activation status for the new record
        $activationStatus = $hasActivatedRecord ? 0 : 1;

        $contact = new Contact();

        $contact->name = $request->name;
        $contact->email = $request->email;
        $contact->tel = $request->tel;
        $contact->map = $request->map;
        $contact->description = $request->description;
        $contact->activation = $activationStatus;

        $contact->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Contact created successfully.'
        );

        return redirect()->route('contacts')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $contact = Contact::find($id);

        return view('backend.contact.edit', compact('contact'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $contact = Contact::find($id);

        $contact->name = $request->name;
        $contact->email = $request->email;
        $contact->tel = $request->tel;
        $contact->map = $request->map;
        $contact->description = $request->description;

        $contact->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Contact update successfully.'
        );

        return redirect()->route('contacts')->with($notification);
    }


    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $contact = Contact::find($request->id);

        Contact::query()->update(['activation' => 0]);

        $contact->activation = $request->activation;
        $contact->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Contact status updated successfully.'
        );

        return response()->json($notification);
    }
    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $contact = Contact::find($id);

        $contact->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Contact deleted successfully.'
        );

        return response()->json($notification);
    }
}
