<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Course;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;
use Carbon\Carbon;

class CourseController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.course.index');
    }

    /**
     * Get the Courses
     */
    public function getCourse()
    {
        $courses = Course::latest()->get();

        return response()->json($courses);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.course.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Check existing course code
        $isExists = Course::where('course_code', $request->course_code)->exists();

        if ($isExists) {
            $notification = array(
                'status' => 'warning',
                'message' => 'Course code already exists.'
            );

            return redirect()->back()->with($notification);
        }

        $course = new Course();

        $course->course_code = $request->course_code;
        $course->title_en = $request->title_en;
        $course->title_kh = $request->title_kh;
        $course->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'course-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/course/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $course->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $course->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Course created successfully.'
        );

        return redirect()->route('major-course.courses')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $course = Course::find($id);

        return view('backend.course.edit', compact('course'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $course = Course::find($id);

        $course->course_code = $request->course_code;
        $course->title_en = $request->title_en;
        $course->title_kh = $request->title_kh;
        $course->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'course-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/course/' . $newFileName);

                // Check and delete existing file
                if ($course->image) {
                    $existingFilePath = public_path('uploads/course/' . $course->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                // Move and rename file to final path
                if (File::exists($tempPath)) {
                    if (File::move($tempPath, $finalPath)) {
                        $course->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $course->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Course updated successfully.'
        );

        return redirect()->route('major-course.courses')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $course = Course::find($request->id);

        $course->activation = $request->activation;
        $course->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Course status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $course = Course::find($request->id);

        $course->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Course deleted successfully.'
        );

        return response()->json($notification);
    }
}
