<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Faculty;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class FacultyController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.faculty.index');
    }

    /**
     * Get the faculties
     */
    public function getFaculties()
    {
        $faculties = Faculty::latest()->get();

        return response()->json($faculties);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.faculty.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $faculty = new Faculty();

        $faculty->title_en = $request->title_en;
        $faculty->title_kh = $request->title_kh;
        $faculty->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'faculty-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/faculty/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $faculty->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $faculty->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Faculty created successfully.'
        );

        return redirect()->route('faculties')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $faculty = Faculty::find($id);

        return view('backend.faculty.edit', compact('faculty'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $faculty = Faculty::find($id);

        $faculty->title_en = $request->title_en;
        $faculty->title_kh = $request->title_kh;
        $faculty->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'faculty-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/faculty/' . $newFileName);

                // Check and delete existing file
                if ($faculty->image) {
                    $existingFilePath = public_path('uploads/faculty/' . $faculty->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                // Move and rename file to final path
                if (File::exists($tempPath)) {
                    if (File::move($tempPath, $finalPath)) {
                        $faculty->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $faculty->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Faculty updated successfully.'
        );

        return redirect()->route('faculties')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $faculty = Faculty::find($request->id);

        $faculty->activation = $request->activation;

        $faculty->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Faculty status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $faculty = Faculty::find($id);

        $faculty->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Faculty deleted successfully.'
        );

        return response()->json($notification);
    }
}
