<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\ResearchInnovationImage;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class FileUploadController extends Controller
{
    public function uploadTemp(Request $request)
    {
        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $fileName = 'temp-' . date('YmdHi') . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('uploads/temp/'), $fileName);

            return response()->json(['fileName' => $fileName]);
        }

        return response()->json(['error' => 'No file uploaded'], 400);
    }

    public function uploadMultipleTemp(Request $request)
    {
        $uploadedFiles = $request->file('images');
        $fileNames = [];

        foreach ($uploadedFiles as $file) {
            $fileName = 'multiple-temp-' . date('YmdHi') . '-' . uniqid() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('uploads/multiple-temp/'), $fileName);
            $fileNames[] = $fileName;
        }

        return response()->json(['fileNames' => $fileNames]);
    }

    public function deleteTemp(Request $request)
    {
        Log::info('deleteTemp called'); // Log to ensure the method is called

        $filename = $request->input('filename') ?? $request->getContent();
        $filename = trim($filename, '"');

        $tempPath = public_path('uploads/temp/' . $filename);

        if (File::exists($tempPath)) {
            if (File::delete($tempPath)) {
                Log::info('File deleted: ' . $tempPath);
                return response()->json(['success' => true, 'message' => 'Temporary file deleted successfully.']);
            } else {
                Log::error('Failed to delete file: ' . $tempPath);
                return response()->json(['success' => false, 'message' => 'Failed to delete the file.']);
            }
        }

        Log::error('File not found: ' . $tempPath);
        return response()->json(['success' => false, 'message' => 'Temporary file not found.'], 404);
    }

    public function deleteMultipleTemp(Request $request)
    {
        // The filename may be sent as raw JSON content or as a POST field
        $filename = $request->input('filename') ?? $request->getContent();
        $filename = trim($filename, '"'); // Trim quotes around the filename if necessary

        // Construct the file path
        $tempPath = public_path('uploads/multiple-temp/' . $filename);

        // Check if the file exists and delete it
        if (File::exists($tempPath)) {
            if (File::delete($tempPath)) {
                return response()->json(['success' => true, 'message' => 'Temporary file deleted successfully.']);
            } else {
                return response()->json(['success' => false, 'message' => 'Failed to delete the file.']);
            }
        }

        return response()->json(['success' => false, 'message' => 'Temporary file not found.'], 404);
    }

    public function deleteProjectImage(Request $request)
    {
        $request->validate([
            'filename' => 'required|string',
        ]);

        $filename = $request->filename;
        $filePath = public_path('uploads/project/gallery/' . $filename);

        if (File::exists($filePath)) {
            File::delete($filePath);

            // Remove the corresponding entry from the database
            ResearchInnovationImage::where('image', $filename)->delete(); // Adjust based on your database structure

            return response()->json(['success' => true, 'message' => 'File deleted successfully from database.']);
        }

        return response()->json(['success' => false, 'message' => 'File not found.'], 404);
    }

    public function deleteTrainingWorkshopImage(Request $request)
    {
        $request->validate([
            'filename' => 'required|string',
        ]);

        $filename = $request->filename;
        $filePath = public_path('uploads/training-workshop/gallery/' . $filename);

        if (File::exists($filePath)) {
            File::delete($filePath);

            // Remove the corresponding entry from the database
            ResearchInnovationImage::where('image', $filename)->delete(); // Adjust based on your database structure

            return response()->json(['success' => true, 'message' => 'File deleted successfully from database.']);
        }

        return response()->json(['success' => false, 'message' => 'File not found.'], 404);
    }

    public function deleteConferenceImage(Request $request)
    {
        $request->validate([
            'filename' => 'required|string',
        ]);

        $filename = $request->filename;
        $filePath = public_path('uploads/conference/gallery/' . $filename);

        if (File::exists($filePath)) {
            File::delete($filePath);

            // Remove the corresponding entry from the database
            ResearchInnovationImage::where('image', $filename)->delete(); // Adjust based on your database structure

            return response()->json(['success' => true, 'message' => 'File deleted successfully from database.']);
        }

        return response()->json(['success' => false, 'message' => 'File not found.'], 404);
    }
}
