<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\History;
use Illuminate\Http\Request;

class HistoryController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $histories = History::latest()->get();

        return view('backend.history.index', compact('histories'));
    }

    /**
     * Get the histories
     */
    public function getHistories()
    {
        $histories = History::latest()->get();

        return response()->json($histories);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.history.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Check if there is at least one record with activation = 1
        $hasActivatedRecord = History::where('activation', 1)->exists();

        // Set activation status for the new record
        $activationStatus = $hasActivatedRecord ? 0 : 1;

        $history = new History();

        $history->title_en = $request->title_en;
        $history->title_kh = $request->title_kh;
        $history->description = $request->description;
        $history->activation = $activationStatus;

        $history->save();

        $notification = array(
            'status' => 'success',
            'message' => 'History created successfully.'
        );

        return redirect()->route('about-us.histories')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $history = History::find($id);

        return view('backend.history.edit', compact('history'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $history = History::find($id);

        $history->title_en = $request->title_en;
        $history->title_kh = $request->title_kh;
        $history->description = $request->description;

        $history->save();

        $notification = array(
            'status' => 'success',
            'message' => 'History updated successfully.'
        );

        return redirect()->route('about-us.histories')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $history = History::find($request->id);

        History::query()->update(['activation' => 0]);

        $history->activation = $request->activation;
        $history->save();

        $notification = array(
            'status' => 'success',
            'message' => 'History status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $history = History::find($id);

        $history->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'History deleted successfully.'
        );

        return response()->json($notification);
    }
}
