<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\HomeSlide;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class HomeSlideController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.home-slide.index');
    }

    /**
     * Get the home slides
     */
    public function getHomeSlides()
    {
        $HomeSlides = HomeSlide::latest()->get();

        return response()->json($HomeSlides);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.home-slide.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $homeSlide = new HomeSlide();

        $homeSlide->title_en = $request->title_en;
        $homeSlide->title_kh = $request->title_kh;
        $homeSlide->sub_title_en = $request->sub_title_en;
        $homeSlide->sub_title_kh = $request->sub_title_kh;
        $homeSlide->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'home-slide-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/home-slide/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $homeSlide->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $homeSlide->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Home Slide created successfully.'
        );

        return redirect()->route('home-slides')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $homeSlide = HomeSlide::find($id);

        return view('backend.home-slide.edit', compact('homeSlide'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $homeSlide = HomeSlide::find($id);

        $homeSlide->title_en = $request->title_en;
        $homeSlide->title_kh = $request->title_kh;
        $homeSlide->sub_title_en = $request->sub_title_en;
        $homeSlide->sub_title_kh = $request->sub_title_kh;
        $homeSlide->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'home-slide-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/home-slide/' . $newFileName);

                // Check and delete existing file
                if ($homeSlide->image) {
                    $existingFilePath = public_path('uploads/home-slide/' . $homeSlide->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $homeSlide->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $homeSlide->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Home Slide updated successfully.'
        );

        return redirect()->route('home-slides')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $homeSlide = HomeSlide::find($request->id);

        $homeSlide->activation = $request->activation;
        $homeSlide->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Home Slide status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $homeSlide = HomeSlide::find($id);

        $homeSlide->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Home Slide deleted successfully.'
        );

        return response()->json($notification);
    }
}
