<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Faculty;
use App\Models\Institute;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class InstituteController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.institute.index');
    }

    /**
     * Get the institutes
     */
    public function getInstitutes()
    {
        //$institutes = Institute::latest()->with('faculties')->get();
        // Join institutes and faculties tables
        $institutes = DB::table('institutes')
            ->leftJoin('faculties', 'institutes.faculty_id', '=', 'faculties.id')
            ->select('institutes.*', 'faculties.title_en as faculty_name')
            ->orderBy('id', 'desc')
            ->get();

        return response()->json($institutes);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $faculties = Faculty::all();

        return view('backend.institute.create', compact('faculties'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $institute = new Institute();

        $institute->title_en = $request->title_en;
        $institute->title_kh = $request->title_kh;
        $institute->faculty_id = $request->faculty_id;
        $institute->description = $request->description;

        $institute->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Institute created successfully.'
        );

        return redirect()->route('institutes')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $faculties = Faculty::all();
        $institute = Institute::find($id);

        return view('backend.institute.edit', compact('faculties', 'institute'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $institute = Institute::find($id);

        $institute->title_en = $request->title_en;
        $institute->title_kh = $request->title_kh;
        $institute->faculty_id = $request->faculty_id;
        $institute->description = $request->description;

        $institute->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Institute updated successfully.'
        );

        return redirect()->route('institutes')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $institute = Institute::find($request->id);

        $institute->activation = $request->activation;
        $institute->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Institute status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $institute = Institute::find($id);

        $institute->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Institute deleted successfully.'
        );

        return response()->json($notification);
    }
}
