<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Institute;
use App\Models\Major;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class MajorController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.major.index');
    }

    /**
     * Get the majors
     */
    public function getMajors()
    {
        $majors = Major::with('institute')->latest()->get();

        return response()->json($majors);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $institutes = Institute::all();

        return view('backend.major.create', compact('institutes'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $major = new Major();

        $major->institute_id = $request->institute_id;
        $major->title_en = $request->title_en;
        $major->title_kh = $request->title_kh;
        $major->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'major-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/major/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $major->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $major->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Major created successfully.'
        );

        return redirect()->route('major-course.majors')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $institutes = Institute::all();
        $major = Major::find($id);

        return view('backend.major.edit', compact('institutes', 'major'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $major = Major::find($id);

        $major->institute_id = $request->institute_id;
        $major->title_en = $request->title_en;
        $major->title_kh = $request->title_kh;
        $major->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'major-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/major/' . $newFileName);

                // Check and delete existing file
                if ($major->image) {
                    $existingFilePath = public_path('uploads/major/' . $major->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                // Move and rename file to final path
                if (File::exists($tempPath)) {
                    if (File::move($tempPath, $finalPath)) {
                        $major->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $major->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Major updated successfully.'
        );

        return redirect()->route('major-course.majors')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $major = Major::find($request->id);

        $major->activation = $request->activation;
        $major->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Major status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $major = Major::find($id);

        $major->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Major deleted successfully.'
        );

        return response()->json($notification);
    }
}
