<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Course;
use App\Models\Major;
use App\Models\MajorCourse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class MajorCourseController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.major-course.index');
    }

    /**
     * Get the majors
     */
    public function getMajorCourses()
    {
        $majors = DB::table('major_courses')
            ->join('majors', 'major_courses.major_id', '=', 'majors.id')
            ->join('courses', 'major_courses.course_id', '=', 'courses.id')
            ->select('major_courses.*', 'majors.title_en as major_name', 'courses.title_en as course_name')
            ->orderBy('id', 'desc')
            ->get();

        return response()->json($majors);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $majors = Major::all();
        $courses = Course::all();

        return view('backend.major-course.create', compact('majors', 'courses'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $majorCourse = new MajorCourse();

        $majorCourse->title = $request->title;
        $majorCourse->major_id = $request->major_id;
        $majorCourse->course_id = $request->course_id;
        $majorCourse->credit = $request->credit;
        $majorCourse->year = $request->year;
        $majorCourse->semester = $request->semester;
        $majorCourse->description = $request->description;

        $majorCourse->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Major Course created successfully.'
        );

        return redirect()->route('major-courses')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $majors = Major::all();
        $courses = Course::all();
        $majorCourse = MajorCourse::find($id);

        return view('backend.major-course.edit', compact('majors', 'courses', 'majorCourse'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $majorCourse = MajorCourse::find($id);

        $majorCourse->title = $request->title;
        $majorCourse->major_id = $request->major_id;
        $majorCourse->course_id = $request->course_id;
        $majorCourse->credit = $request->credit;
        $majorCourse->year = $request->year;
        $majorCourse->semester = $request->semester;
        $majorCourse->description = $request->description;

        $majorCourse->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Major Course updated successfully.'
        );

        return redirect()->route('major-courses')->with($notification);
    }
    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $majorCourse = MajorCourse::find($request->id);

        $majorCourse->activation = $request->activation;
        $majorCourse->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Major Course status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $majorCourse = MajorCourse::find($id);

        $majorCourse->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Major Course deleted successfully.'
        );

        return response()->json($notification);
    }
}
