<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\MissionVision;
use Illuminate\Http\Request;
use Mockery\Exception;

class MissionVisionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.mission-vision.index');
    }

    /**
     * Display a listing of the resource.
     */
    public function getMissionVisions()
    {
        $missionVisions = MissionVision::latest()->get();

        return response()->json($missionVisions);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.mission-vision.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Check if there is at least one record with activation = 1
        $hasActivatedRecord = MissionVision::where('activation', 1)->exists();

        // Set activation status for the new record
        $activationStatus = $hasActivatedRecord ? 0 : 1;

        $missionVision = new MissionVision();

        $missionVision->mission = $request->mission;
        $missionVision->vision = $request->vision;
        $missionVision->activation = $activationStatus;

        $missionVision->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Mission & Vision created successfully.'
        );

        return redirect()->route('about-us.mission-visions')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $missionVision = MissionVision::find($id);

        return view('backend.mission-vision.edit', compact('missionVision'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $missionVision = MissionVision::find($id);

        $missionVision->mission = $request->mission;
        $missionVision->vision = $request->vision;

        $missionVision->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Mission & Vision updated successfully.'
        );

        return redirect()->route('about-us.mission-visions')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $missionVision = MissionVision::find($request->id);

        MissionVision::query()->update(['activation' => 0]);

        $missionVision->activation = $request->activation;
        $missionVision->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Mission & Vision status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $missionVision = MissionVision::find($id);

        $missionVision->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Mission & Vision deleted successfully.'
        );

        return response()->json($notification);
    }
}
