<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\NewsActivity;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class NewsActivityController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.news-activity.index');
    }

    /**
     * Get the news & activities
     */
    public function getNewsActivities()
    {
        $newsActivities = NewsActivity::latest()->get();

        return response()->json($newsActivities);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.news-activity.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $newsActivity = new NewsActivity();

        $newsActivity->title_en = $request->title_en;
        $newsActivity->title_kh = $request->title_kh;
        $newsActivity->sub_title_en = $request->sub_title_en;
        $newsActivity->sub_title_kh = $request->sub_title_kh;
        $newsActivity->date = date('Y-m-d H:i', strtotime($request->date));
        $newsActivity->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'news-activity-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/news-activity/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $newsActivity->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $newsActivity->save();

        $notification = array(
            'status' => 'success',
            'message' => 'News & Activity created successfully.'
        );

        return redirect()->route('news-activities')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $newsActivity = NewsActivity::find($id);

        return view('backend.news-activity.edit', compact('newsActivity'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $newsActivity = NewsActivity::find($id);

        $newsActivity->title_en = $request->title_en;
        $newsActivity->title_kh = $request->title_kh;
        $newsActivity->sub_title_en = $request->sub_title_en;
        $newsActivity->sub_title_kh = $request->sub_title_kh;
        $newsActivity->date = date('Y-m-d H:i', strtotime($request->date));
        $newsActivity->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'news-activity-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/news-activity/' . $newFileName);

                // Check and delete existing file
                if ($newsActivity->image) {
                    $existingFilePath = public_path('uploads/news-activity/' . $newsActivity->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                // Move and rename file to final path
                if (File::exists($tempPath)) {
                    if (File::move($tempPath, $finalPath)) {
                        $newsActivity->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $newsActivity->save();

        $notification = array(
            'status' => 'success',
            'message' => 'News & Activity Update successfully.'
        );

        return redirect()->route('news-activities')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $newsActivity = NewsActivity::find($request->id);

        $newsActivity->activation = $request->activation;
        $newsActivity->save();

        $notification = array(
            'status' => 'success',
            'message' => 'News & Activity status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $newsActivity = NewsActivity::find($id);

        $newsActivity->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'News & Activity deleted successfully.'
        );

        return response()->json($notification);
    }
}
