<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\PresidentMessage;
use Illuminate\Http\Request;

class PresidentMessageController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.president-message.index');
    }

    /**
     * Display a listing of the resource.
     */
    public function getPresidentMessages()
    {
        $presidentMessage = PresidentMessage::latest()->get();

        return response()->json($presidentMessage);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.president-message.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Check if there is at least one record with activation = 1
        $hasActivatedRecord = PresidentMessage::where('activation', 1)->exists();

        // Set activation status for the new record
        $activationStatus = $hasActivatedRecord ? 0 : 1;

        $presidentMessage = new PresidentMessage();

        $presidentMessage->description = $request->description;
        $presidentMessage->activation = $activationStatus;

        $presidentMessage->save();

        $notification = array(
            'status' => 'success',
            'message' => 'President created successfully.'
        );

        return redirect()->route('about-us.president-messages')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $presidentMessage = PresidentMessage::find($id);

        return view('backend.president-message.edit', compact('presidentMessage'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $presidentMessage = PresidentMessage::find($id);

        $presidentMessage->description = $request->description;

        $presidentMessage->save();

        $notification = array(
            'status' => 'success',
            'message' => 'President updated successfully.'
        );

        return redirect()->route('about-us.president-messages')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $presidentMessage = PresidentMessage::find($request->id);

        PresidentMessage::query()->update(['activation' => 0]);

        $presidentMessage->activation = $request->activation;
        $presidentMessage->save();

        $notification = array(
            'status' => 'success',
            'message' => 'President Message status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $presidentMessage = PresidentMessage::find($id);

        $presidentMessage->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'President deleted successfully.'
        );

        return response()->json($notification);
    }
}
