<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class ProfileController extends Controller
{
    /**
     * Show the form for editing the specified resource.
     */
    public function edit()
    {
        $profileData = User::find(Auth::user()->id);

        return view('backend.profile.edit-profile', compact('profileData'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function editPassword()
    {
        return view('backend.profile.edit-password');
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request)
    {
        $profileData = User::find(Auth::user()->id);

        $profileData->first_name_en = $request->first_name_en;
        $profileData->middle_name_en = $request->middle_name_en;
        $profileData->last_name_en = $request->last_name_en;
        $profileData->first_name_kh = $request->first_name_kh;
        $profileData->middle_name_kh = $request->middle_name_kh;
        $profileData->last_name_kh = $request->last_name_kh;
        $profileData->email = $request->email;
        $profileData->sex = $request->sex;
        $profileData->dob = date('Y-m-d', strtotime($request->dob));
        $profileData->tel = $request->tel;
        $profileData->birth_place = $request->birth_place;
        $profileData->present_address = $request->present_address;

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $fileName = 'avatar' . date('YmdHi') . '.' . $file->getClientOriginalExtension();
            @unlink(public_path('uploads/avatars/'.$profileData->photo));
            $file->move(public_path('uploads/avatars'), $fileName);
            $profileData->photo = $fileName;
        }

        $profileData->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Profile updated successfully.'
        );

        return redirect()->back()->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function updatePassword(Request $request)
    {
        // Check the password
        if (!Hash::check($request->current_password, auth::user()->password)) {
            $notification = array(
                'status' => 'error',
                'message' => 'Current password does not match!'
            );

            return back()->with($notification);
        }

        // Update the password
        User::whereId(auth::user()->id)->update([
            'password' => Hash::make($request->new_password)
        ]);

        $notification = array(
            'status' => 'success',
            'message' => 'Password updated successfully.'
        );

        return redirect()->back()->with($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
}
