<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Project;
use App\Models\ResearchInnovationImage;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class ProjectController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.project.index');
    }

    /**
     * Get the projects
     */
    public function getProjects()
    {
        $projects = Project::latest()->get();

        return response()->json($projects);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.project.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $project = new Project();

        $project->title_en = $request->title_en;
        $project->title_kh = $request->title_kh;
        $project->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'project-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/project/' . $newFileName);

                // Debugging logs
                Log::info("Temp Path: $tempPath");
                Log::info("Final Path: $finalPath");

                if (File::exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        Log::info("File moved successfully from $tempPath to $finalPath");
                        $project->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $project->save();

        // Handle multiple image uploads
        if ($request->images) {
            foreach ($request->images as $image) {
                // Ensure each image data is JSON decoded
                $imageData = json_decode($image, true);
                if (isset($imageData['fileNames'])) {
                    foreach ($imageData['fileNames'] as $tempFileName) {
                        $tempPath = public_path('uploads/multiple-temp/' . $tempFileName);

                        // Generate new file name
                        $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                        $newFileName = 'gallery-image-' . date('YmdHi') . '-' . uniqid() . '.' . $extension;
                        $finalPath = public_path('uploads/project/gallery/' . $newFileName);

                        // Debugging logs
                        Log::info("Temp Path: $tempPath");
                        Log::info("Final Path: $finalPath");

                        // Move and rename file to final path
                        if (File::exists($tempPath)) {
                            if (rename($tempPath, $finalPath)) {
                                Log::info("File moved successfully from $tempPath to $finalPath");
                                ResearchInnovationImage::create([
                                    'project_id' => $project->id,
                                    'image' => $newFileName,
                                ]);
                            } else {
                                Log::error("Failed to move file from $tempPath to $finalPath");
                            }
                        } else {
                            Log::error("Temporary file not found: " . $tempPath);
                        }
                    }
                } else {
                    Log::error("File names not found in image data: " . $image);
                }
            }
        }

        $notification = array(
            'status' => 'success',
            'message' => 'Project created successfully.'
        );

        return redirect()->route('research-innovation.projects')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $project = Project::with('images')->find($id);

        return view('backend.project.edit', compact('project'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $project = Project::find($id);

        $project->title_en = $request->title_en;
        $project->title_kh = $request->title_kh;
        $project->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'project-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/project/' . $newFileName);

                // Check and delete existing file
                if ($project->image) {
                    $existingFilePath = public_path('uploads/project/' . $project->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                // Move and rename file to final path
                if (File::exists($tempPath)) {
                    if (File::move($tempPath, $finalPath)) {
                        $project->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        // Handle multiple image uploads
        if ($request->images) {
            foreach ($request->images as $image) {
                // Ensure each image data is JSON decoded
                $imageData = json_decode($image, true);
                if (isset($imageData['fileNames'])) {
                    foreach ($imageData['fileNames'] as $tempFileName) {
                        $tempPath = public_path('uploads/multiple-temp/' . $tempFileName);

                        // Generate new file name
                        $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                        $newFileName = 'gallery-image-' . date('YmdHi') . '-' . uniqid() . '.' . $extension;
                        //$newImageFilenames[] = $newFileName; // Store the new filename
                        $finalPath = public_path('uploads/project/gallery/' . $newFileName);

                        // Debugging logs
                        Log::info("Temp Path: $tempPath");
                        Log::info("Final Path: $finalPath");

                        // Move and rename file to final path
                        if (File::exists($tempPath)) {
                            if (rename($tempPath, $finalPath)) {
                                Log::info("File moved successfully from $tempPath to $finalPath");
                                ResearchInnovationImage::create([
                                    'project_id' => $project->id,
                                    'image' => $newFileName,
                                ]);
                            } else {
                                Log::error("Failed to move file from $tempPath to $finalPath");
                            }
                        } else {
                            Log::error("Temporary file not found: " . $tempPath);
                        }
                    }
                } else {
                    Log::error("File names not found in image data: " . $image);
                }
            }
        }

        $project->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Project updated successfully.'
        );

        return redirect()->route('research-innovation.projects')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $project = Project::find($request->id);

        $project->activation = $request->activation;

        $project->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Project status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $project = Project::find($id);

        $project->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Project deleted successfully.'
        );

        return response()->json($notification);
    }
}
