<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\PublicationBook;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class PublicationBookController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.publication-book.index');
    }

    /**
     * Get the publication books
     */
    public function getPublicationBooks()
    {
        $publicationBooks = PublicationBook::latest()->get();

        return response()->json($publicationBooks);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.publication-book.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $publicationBook = new PublicationBook();

        $publicationBook->title_en = $request->title_en;
        $publicationBook->title_kh = $request->title_kh;
        $publicationBook->author = $request->author;
        $publicationBook->date_published = date('Y-m-d', strtotime($request->date_published));
        $publicationBook->url = $request->url;
        $publicationBook->doi = $request->doi;
        $publicationBook->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'publication-book-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/publication-book/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $publicationBook->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $publicationBook->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Publication Book created successfully.'
        );

        return redirect()->route('research-innovation.publication-books')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $publicationBook = PublicationBook::find($id);

        return view('backend.publication-book.edit', compact('publicationBook'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $publicationBook = PublicationBook::find($id);

        $publicationBook->title_en = $request->title_en;
        $publicationBook->title_kh = $request->title_kh;
        $publicationBook->author = $request->author;
        $publicationBook->date_published = date('Y-m-d', strtotime($request->date_published));
        $publicationBook->url = $request->url;
        $publicationBook->doi = $request->doi;
        $publicationBook->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'publication-book-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/publication-book/' . $newFileName);

                // Check and delete existing file
                if ($publicationBook->image) {
                    $existingFilePath = public_path('uploads/publication-book/' . $publicationBook->image);
                    if (File::exists($existingFilePath)) {
                        File::delete($existingFilePath);
                    }
                }

                // Move and rename file to final path
                if (File::exists($tempPath)) {
                    if (File::move($tempPath, $finalPath)) {
                        $publicationBook->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $publicationBook->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Publication Book created successfully.'
        );

        return redirect()->route('research-innovation.publication-books')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $publicationBook = PublicationBook::find($request->id);

        $publicationBook->activation = $request->activation;

        $publicationBook->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Publication Book status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $publicationBook = PublicationBook::find($id);

        $publicationBook->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Publication Book deleted successfully.'
        );

        return response()->json($notification);
    }
}
