<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\ResearchInnovationImage;
use App\Models\TrainingWorkshop;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Log;

class TrainingWorkshopController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.training-workshop.index');
    }

    /**
     * Get the training & workshop
     */
    public function getTrainingWorkshops()
    {
        $trainingWorkshops = TrainingWorkshop::latest()->get();

        return response()->json($trainingWorkshops);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.training-workshop.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $trainingWorkshop = new TrainingWorkshop();

        $trainingWorkshop->title_en = $request->title_en;
        $trainingWorkshop->title_kh = $request->title_kh;
        $trainingWorkshop->sub_title_en = $request->sub_title_en;
        $trainingWorkshop->sub_title_kh = $request->sub_title_kh;
        $trainingWorkshop->start_date = date('Y-m-d', strtotime($request->start_date));
        $trainingWorkshop->end_date = date('Y-m-d', strtotime($request->end_date));
        $trainingWorkshop->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'training-workshop-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/training-workshop/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $trainingWorkshop->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        $trainingWorkshop->save();

        // Handle multiple image uploads
        if ($request->images) {
            foreach ($request->images as $image) {
                // Ensure each image data is JSON decoded
                $imageData = json_decode($image, true);
                if (isset($imageData['fileNames'])) {
                    foreach ($imageData['fileNames'] as $tempFileName) {
                        $tempPath = public_path('uploads/multiple-temp/' . $tempFileName);

                        // Generate new file name
                        $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                        $newFileName = 'gallery-image-' . date('YmdHi') . '-' . uniqid() . '.' . $extension;
                        $finalPath = public_path('uploads/training-workshop/gallery/' . $newFileName);

                        // Debugging logs
                        Log::info("Temp Path: $tempPath");
                        Log::info("Final Path: $finalPath");

                        // Move and rename file to final path
                        if (File::exists($tempPath)) {
                            if (rename($tempPath, $finalPath)) {
                                Log::info("File moved successfully from $tempPath to $finalPath");
                                ResearchInnovationImage::create([
                                    'training_workshop_id' => $trainingWorkshop->id,
                                    'image' => $newFileName,
                                ]);
                            } else {
                                Log::error("Failed to move file from $tempPath to $finalPath");
                            }
                        } else {
                            Log::error("Temporary file not found: " . $tempPath);
                        }
                    }
                } else {
                    Log::error("File names not found in image data: " . $image);
                }
            }
        }

        $notification = array(
            'status' => 'success',
            'message' => 'Training & Workshop created successfully.'
        );

        return redirect()->route('research-innovation.training-workshops')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $trainingWorkshop = TrainingWorkshop::with('images')->find($id);

        return view('backend.training-workshop.edit', compact('trainingWorkshop'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $trainingWorkshop = TrainingWorkshop::find($id);

        $trainingWorkshop->title_en = $request->title_en;
        $trainingWorkshop->title_kh = $request->title_kh;
        $trainingWorkshop->sub_title_en = $request->sub_title_en;
        $trainingWorkshop->sub_title_kh = $request->sub_title_kh;
        $trainingWorkshop->start_date = date('Y-m-d', strtotime($request->start_date));
        $trainingWorkshop->end_date = date('Y-m-d', strtotime($request->end_date));
        $trainingWorkshop->description = $request->description;

        if ($request->image) {
            $imageData = json_decode($request->image, true);
            if (isset($imageData['fileName'])) {
                $tempFileName = $imageData['fileName'];
                $tempPath = public_path('uploads/temp/' . $tempFileName);

                // Generate new file name
                $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                $newFileName = 'training-workshop-image-' . date('YmdHi') . '.' . $extension;
                $finalPath = public_path('uploads/training-workshop/' . $newFileName);

                if (file_exists($tempPath)) {
                    // Move and rename file to final path
                    if (rename($tempPath, $finalPath)) {
                        $trainingWorkshop->image = $newFileName;
                    } else {
                        Log::error("Failed to move file from $tempPath to $finalPath");
                    }
                } else {
                    Log::error("Temporary file not found: " . $tempPath);
                }
            } else {
                Log::error("File name not found in image data: " . $request->image);
            }
        }

        // Handle multiple image uploads
        if ($request->images) {
            foreach ($request->images as $image) {
                // Ensure each image data is JSON decoded
                $imageData = json_decode($image, true);
                if (isset($imageData['fileNames'])) {
                    foreach ($imageData['fileNames'] as $tempFileName) {
                        $tempPath = public_path('uploads/multiple-temp/' . $tempFileName);

                        // Generate new file name
                        $extension = pathinfo($tempFileName, PATHINFO_EXTENSION);
                        $newFileName = 'gallery-image-' . date('YmdHi') . '-' . uniqid() . '.' . $extension;
                        $finalPath = public_path('uploads/training-workshop/gallery/' . $newFileName);

                        // Debugging logs
                        Log::info("Temp Path: $tempPath");
                        Log::info("Final Path: $finalPath");

                        // Move and rename file to final path
                        if (File::exists($tempPath)) {
                            if (rename($tempPath, $finalPath)) {
                                Log::info("File moved successfully from $tempPath to $finalPath");
                                ResearchInnovationImage::create([
                                    'training_workshop_id' => $trainingWorkshop->id,
                                    'image' => $newFileName,
                                ]);
                            } else {
                                Log::error("Failed to move file from $tempPath to $finalPath");
                            }
                        } else {
                            Log::error("Temporary file not found: " . $tempPath);
                        }
                    }
                } else {
                    Log::error("File names not found in image data: " . $image);
                }
            }
        }

        $trainingWorkshop->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Training & Workshop updated successfully.'
        );

        return redirect()->route('research-innovation.training-workshops')->with($notification);
    }

    /**
     * Update the specified resource in storage.
     */
    public function status(Request $request)
    {
        $trainingWorkshop = TrainingWorkshop::find($request->id);

        $trainingWorkshop->activation = $request->activation;
        $trainingWorkshop->save();

        $notification = array(
            'status' => 'success',
            'message' => 'Training & Workshop status updated successfully.'
        );

        return response()->json($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $trainingWorkshop = TrainingWorkshop::find($id);

        $trainingWorkshop->delete();

        $notification = array(
            'status' => 'success',
            'message' => 'Training & Workshop deleted successfully.'
        );

        return response()->json($notification);
    }
}
