<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class UserRoleController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('backend.user-role.index');
    }

    /**
     * Get the user roles
     */
    public function getUserRoles()
    {
        $userRoles = DB::table('roles')->latest()->get();

        return response()->json($userRoles);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $permissions = Permission::all();
        $permissionsGroups = User::getPermissionGroups();

        return view('backend.user-role.create', compact( 'permissions', 'permissionsGroups'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $data = array();
        $permissions = $request->permissions;

        $role = new Role();
        $role->name = $request->name;

        $role->save();

        foreach ($permissions as $permission) {
            $data['role_id'] = $role->id;
            $data['permission_id'] = $permission;

            DB::table('role_has_permissions')->insert($data);
        }

        $notification = array(
            'status' => 'success',
            'message' => 'User Role created successfully.'
        );

        return redirect()->route('user.role')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $role = Role::find($id);
        $permissions = Permission::all();
        $permissionsGroups = User::getPermissionGroups();

        return view('backend.user-role.edit', compact( 'role', 'permissions', 'permissionsGroups'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $role = Role::find($id);
        $permissions = $request->permissions;

        if (!empty($permissions)) {
            $permissionNames = Permission::whereIn('id', $permissions)->pluck('name')->toArray();
            $role->syncPermissions($permissionNames);
        } else {
            $role->syncPermissions([]);
        }

        $notification = array(
            'status' => 'success',
            'message' => 'User Role updated successfully.'
        );

        return redirect()->route('user.role')->with($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $role = Role::find($id);

        if (!is_null($role)) {
            $role->delete();
        }

        $notification = array(
            'status' => 'success',
            'message' => 'User Role delete successfully.'
        );

        return response()->json($notification);
    }
}
