<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\DB;
use Spatie\Permission\Traits\HasRoles;

class User extends Authenticatable
{
    use HasFactory, Notifiable, HasRoles;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $guarded = [];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed',
        ];
    }

    /**
     * Get the permission by groups.
     *
     *
     */
    public static function getPermissionGroups(): \Illuminate\Support\Collection
    {
        return DB::table('permissions')
            ->select('group_name')
            ->groupBy('group_name')
            ->orderBy('id')
            ->get();
    }

    /**
     * Get the permission by group name.
     *
     *
     */
    public static function getPermissionGroupName($groupName): \Illuminate\Support\Collection
    {
        return DB::table('permissions')
            ->select('id', 'name')
            ->where('group_name', $groupName)
            ->get();
    }

    /**
     * Get the role has permission.
     *
     *
     */
    public static function roleHasPermissions($role, $permissions): bool
    {
        $hasPermission = true;

        foreach ($permissions as $permission) {
            if (!$role->hasPermissionTo($permission->name)) {
                $hasPermission = false;
            }

            return $hasPermission;
        }

        return true;
    }
}
