@extends('layouts.contentNavbarLayoutBackend')

@section('title', 'Edit Career')

@section('vendor-style')
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond-plugin-image-preview.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond-plugin-file-poster.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/flatpickr/flatpickr.css') }}">
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/@form-validation/form-validation.css') }}"/>
@endsection

@section('page-style')
    <style>
        .ck-editor__editable_inline {
            min-height: 300px;
        }
    </style>
@endsection

@section('vendor-script')
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-image-preview.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-poster.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-validate-size.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-validate-type.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/flatpickr/flatpickr.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/ckeditor5/ckeditor.min.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/popular.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/bootstrap5.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/auto-focus.js') }}"></script>
@endsection

@section('page-script')
    <script type="text/javascript">
        $(document).ready(function () {
            // Register the plugins
            FilePond.registerPlugin(
                FilePondPluginImagePreview,
                FilePondPluginFilePoster,
                FilePondPluginFileValidateSize,
                FilePondPluginFileValidateType
            );

            // Turn all file input elements into ponds
            const inputElement = document.querySelector('input[name="image"]');
            const pond = FilePond.create(inputElement, {
                imagePreviewHeight: 250,
                filePosterHeight: 250,
                allowMultiple: false,
                server: {
                    process: {
                        url: '/upload-temp',
                        method: 'POST',
                        headers: {
                            'X-CSRF-TOKEN': '{{ csrf_token() }}'
                        }
                    },
                    load: {
                        url: '{{ asset('uploads/career/' . $career->image) }}',
                        method: 'GET',
                        headers: {
                            'X-CSRF-TOKEN': '{{ csrf_token() }}'
                        },
                        withCredentials: false,
                    },
                },
                files: [
                    @if ($career->image)
                    {
                        source: '{{ asset('uploads/career/' . $career->image) }}',
                        options: {
                            type: 'local',
                            file: {
                                name: '{{ $career->image }}',
                                size: {{ filesize(public_path('uploads/career/' . $career->image)) }},
                                type: 'image/{{ pathinfo($career->image, PATHINFO_EXTENSION) }}'
                            },
                            metadata: {
                                poster: '{{ asset('uploads/career/' . $career->image) }}'
                            }
                        }
                    }
                    @endif
                ]
            });

            const startDate = $('#start_date').flatpickr({
                dateFormat: "d-M-Y",
                onChange: function (selectedDates) {
                    endDate.set("minDate", selectedDates[0]);
                }
            });
            const endDate = $('#end_date').flatpickr({
                dateFormat: "d-M-Y"
            });

            ClassicEditor
                .create( document.querySelector( '#description' ),{
                    ckfinder: {
                        uploadUrl: '{{route('ckeditor.upload').'?_token='.csrf_token()}}',
                    }
                }).catch( error => {} );

            const formValidation = document.getElementById('careerForm');

            const fv = FormValidation.formValidation(formValidation, {
                fields: {
                    title_en: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter title in english'
                            }
                        }
                    },
                    title_kh: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter title in khmer'
                            }
                        }
                    },
                },
                plugins: {
                    trigger: new FormValidation.plugins.Trigger(),
                    bootstrap5: new FormValidation.plugins.Bootstrap5({
                        // Use this for enabling/changing valid/invalid class
                        // eleInvalidClass: '',
                        eleValidClass: '',
                        rowSelector: function(field, ele) {
                            // field is the field name & ele is the field element
                            switch (field) {
                                case 'title_en':
                                case 'title_kh':
                                default:
                                    return '.row';
                            }
                        }
                    }),
                    submitButton: new FormValidation.plugins.SubmitButton(),
                    // Submit the form when all fields are valid
                    defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
                    autoFocus: new FormValidation.plugins.AutoFocus()
                },
                init: instance => {
                    instance.on('plugins.message.placed', function(e) {
                        //* Move the error message out of the `input-group` element
                        if (e.element.parentElement.classList.contains('input-group')) {
                            // `e.field`: The field name
                            // `e.messageElement`: The message element
                            // `e.element`: The field element
                            e.element.parentElement.insertAdjacentElement('afterend', e.messageElement);
                        }
                        //* Move the error message out of the `row` element for custom-options
                        if (e.element.parentElement.parentElement.classList.contains('custom-option')) {
                            e.element.closest('.row').insertAdjacentElement('afterend', e.messageElement);
                        }
                    });
                }
            });
        });
    </script>
@endsection

@section('content')
    <form id="careerForm" action="{{ route('careers.update', $career->id) }}" method="POST" autocomplete="off" enctype="multipart/form-data">
        @csrf
        <div class="d-flex flex-wrap justify-content-between align-items-center mb-3">
            <div class="d-flex flex-column justify-content-center">
                <h4 class="mb-1 mt-3">Edit Career</h4>
                <p class="text-muted">Enter career data</p>
            </div>
            <div class="d-flex align-content-center flex-wrap gap-3">
                <a href="{{ route('careers') }}" class="btn btn-label-secondary">Back</a>
                <button type="submit" class="btn btn-primary">Save</button>
            </div>
        </div>

        <div class="card">
            <div class="card-body">
                <div class="row g-3">
                    <div class="col-xxl-12 col-xl-12 col-lg-12 col-md-12 col-sm-12">
                        <label class="form-label" for="image">Image</label>
                        <input type="file" class="filepond" id="image" name="image" data-max-file-size="3MB" data-max-files="1">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="title_en">Title in English</label>
                        <input type="text" class="form-control" id="title_en" name="title_en" value="{{ $career->title_en }}" placeholder="Enter Title in English">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="title_kh">Title in Khmer</label>
                        <input type="text" class="form-control" id="title_kh" name="title_kh" value="{{ $career->title_kh }}" placeholder="Enter Title in Khmer">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="position">Position</label>
                        <input type="text" class="form-control" id="position" name="position" value="{{ $career->position }}" placeholder="Enter Position">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="company">Company</label>
                        <input type="text" class="form-control" id="company" name="company" value="{{ $career->company }}" placeholder="Enter Company">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="website">Website</label>
                        <input type="text" class="form-control" id="website" name="website" value="{{ $career->website }}" placeholder="Enter Website">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="email">Email</label>
                        <input type="text" class="form-control" id="email" name="email" value="{{ $career->email }}" placeholder="Enter Email">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="tel">Tel</label>
                        <input type="text" class="form-control" id="tel" name="tel" value="{{ $career->tel }}" placeholder="Enter Tel">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="number">Number of Require</label>
                        <input type="text" class="form-control" id="number" name="number" value="{{ $career->number }}" placeholder="Enter Number of Require">
                    </div>
                    <div class="col-xxl-12 col-xl-12 col-lg-12 col-md-12 col-sm-12">
                        <label class="form-label" for="location">Location</label>
                        <input type="text" class="form-control" id="location" name="location" value="{{ $career->location }}" placeholder="Enter Location">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="start_date">Start Date</label>
                        <input type="text" class="form-control" id="start_date" name="start_date" value="{{ date('d-M-Y', strtotime($career->start_date)) }}" placeholder="DD-MM-YYYY">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="end_date">End Date</label>
                        <input type="text" class="form-control" id="end_date" name="end_date" value="{{ date('d-M-Y', strtotime($career->end_date)) }}" placeholder="DD-MM-YYYY">
                    </div>
                    <div class="col-xxl-12 col-xl-12 col-lg-12 col-md-12 col-sm-12">
                        <label class="form-label" for="description">Description</label>
                        <textarea class="form-control" id="description" name="description" placeholder="Enter Description" cols="30" rows="14">{!! $career->description !!}</textarea>
                    </div>
                </div>
            </div>
        </div>
    </form>
@endsection
