@extends('layouts.contentNavbarLayoutBackend')

@section('title', 'Edit Course')

@section('vendor-style')
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond-plugin-image-preview.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond-plugin-file-poster.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/@form-validation/form-validation.css') }}"/>
@endsection

@section('page-style')
    <style>
        .ck-editor__editable_inline {
            min-height: 300px;
        }
    </style>
@endsection

@section('vendor-script')
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-image-preview.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-poster.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-validate-size.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-validate-type.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/ckeditor5/ckeditor.min.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/popular.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/bootstrap5.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/auto-focus.js') }}"></script>
@endsection

@section('page-script')
    <script type="text/javascript">
        $(document).ready(function () {
            // Register the plugins
            FilePond.registerPlugin(
                FilePondPluginImagePreview,
                FilePondPluginFilePoster,
                FilePondPluginFileValidateSize,
                FilePondPluginFileValidateType
            );

            // Turn all file input elements into ponds
            const inputElement = document.querySelector('input[name="image"]');
            const pond = FilePond.create(inputElement, {
                imagePreviewHeight: 250,
                filePosterHeight: 250,
                allowMultiple: false,
                server: {
                    process: {
                        url: '/upload-temp',
                        method: 'POST',
                        headers: {
                            'X-CSRF-TOKEN': '{{ csrf_token() }}'
                        }
                    },
                    load: {
                        url: '{{ asset('uploads/course/' . $course->image) }}',
                        method: 'GET',
                        headers: {
                            'X-CSRF-TOKEN': '{{ csrf_token() }}'
                        },
                        withCredentials: false,
                    },
                },
                files: [
                    @if ($course->image)
                    {
                        source: '{{ asset('uploads/course/' . $course->image) }}',
                        options: {
                            type: 'local',
                            file: {
                                name: '{{ $course->image }}',
                                size: {{ filesize(public_path('uploads/course/' . $course->image)) }},
                                type: 'image/{{ pathinfo($course->image, PATHINFO_EXTENSION) }}'
                            },
                            metadata: {
                                poster: '{{ asset('uploads/course/' . $course->image) }}'
                            }
                        }
                    }
                    @endif
                ]
            });

            ClassicEditor
                .create( document.querySelector( '#description' ),{
                    ckfinder: {
                        uploadUrl: '{{route('ckeditor.upload').'?_token='.csrf_token()}}',
                    }
                }).catch( error => {} );

            const formValidation = document.getElementById('courseForm');

            FormValidation.formValidation(formValidation, {
                fields: {
                    course_code: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter course code'
                            }
                        }
                    },
                    title_en: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter title in english'
                            }
                        }
                    },
                    title_kh: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter title in khmer'
                            }
                        }
                    },
                },
                plugins: {
                    trigger: new FormValidation.plugins.Trigger(),
                    bootstrap5: new FormValidation.plugins.Bootstrap5({
                        // Use this for enabling/changing valid/invalid class
                        // eleInvalidClass: '',
                        eleValidClass: '',
                        rowSelector: function(field, ele) {
                            // field is the field name & ele is the field element
                            switch (field) {
                                case 'title_en':
                                case 'title_kh':
                                default:
                                    return '.row';
                            }
                        }
                    }),
                    submitButton: new FormValidation.plugins.SubmitButton(),
                    // Submit the form when all fields are valid
                    defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
                    autoFocus: new FormValidation.plugins.AutoFocus()
                },
                init: instance => {
                    instance.on('plugins.message.placed', function(e) {
                        //* Move the error message out of the `input-group` element
                        if (e.element.parentElement.classList.contains('input-group')) {
                            // `e.field`: The field name
                            // `e.messageElement`: The message element
                            // `e.element`: The field element
                            e.element.parentElement.insertAdjacentElement('afterend', e.messageElement);
                        }
                        //* Move the error message out of the `row` element for custom-options
                        if (e.element.parentElement.parentElement.classList.contains('custom-option')) {
                            e.element.closest('.row').insertAdjacentElement('afterend', e.messageElement);
                        }
                    });
                }
            });
        });
    </script>
@endsection

@section('content')
    <form id="courseForm" action="{{ route('major-course.courses.update', $course->id) }}" method="POST" autocomplete="off" enctype="multipart/form-data">
        @csrf
        <div class="d-flex flex-wrap justify-content-between align-items-center mb-3">
            <div class="d-flex flex-column justify-content-center">
                <h4 class="mb-1 mt-3">Edit Course</h4>
                <p class="text-muted">Enter course data</p>
            </div>
            <div class="d-flex align-content-center flex-wrap gap-3">
                <a href="{{ route('major-course.courses') }}" class="btn btn-label-secondary">Back</a>
                <button type="submit" class="btn btn-primary">Save</button>
            </div>
        </div>

        <div class="card">
            <div class="card-body">
                <div class="row g-3">
                    <div class="col-lg-12">
                        <label class="form-label" for="image">Image</label>
                        <input type="file" class="filepond" id="image" name="image" data-max-file-size="3MB" data-max-files="1">
                    </div>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-4 col-sm-12">
                        <label class="form-label" for="course_code">Course Code</label>
                        <input type="text" class="form-control" id="course_code" name="course_code" value="{{ $course->course_code }}" placeholder="Enter Course Code">
                    </div>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-4 col-sm-12">
                        <label class="form-label" for="title_en">Title in English</label>
                        <input type="text" class="form-control" id="title_en" name="title_en" value="{{ $course->title_en }}" placeholder="Enter Title in English">
                    </div>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-4 col-sm-12">
                        <label class="form-label" for="title_kh">Title in Khmer</label>
                        <input type="text" class="form-control" id="title_kh" name="title_kh" value="{{ $course->title_kh }}" placeholder="Enter Title in Khmer">
                    </div>
                    <div class="col-lg-12">
                        <label class="form-label" for="description">Description</label>
                        <textarea class="form-control" id="description" name="description" placeholder="Enter Description" cols="30" rows="14">{!! $course->description !!}</textarea>
                    </div>
                </div>
            </div>
        </div>
    </form>
@endsection
