@extends('layouts.contentNavbarLayoutBackend')

@section('title', 'Create Major Course')

@section('vendor-style')
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/select2/select2.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/bootstrap-datepicker/bootstrap-datepicker.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/@form-validation/form-validation.css') }}"/>
@endsection

@section('page-style')
    <style>
        .ck-editor__editable_inline {
            min-height: 300px;
        }
    </style>
@endsection

@section('vendor-script')
    <script src="{{ asset('backend-assets/vendor/libs/select2/select2.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/bootstrap-datepicker/bootstrap-datepicker.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/ckeditor5/ckeditor.min.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/popular.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/bootstrap5.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/auto-focus.js') }}"></script>
@endsection

@section('page-script')
    <script type="text/javascript">
        $(document).ready(function () {
            // Initialize Select2
            $('.select2').select2();

            ClassicEditor
                .create( document.querySelector( '#description' ),{
                    ckfinder: {
                        uploadUrl: '{{route('ckeditor.upload').'?_token='.csrf_token()}}',
                    }
                }).catch( error => {} );

            const formValidation = document.getElementById('majorCourseForm');

            const fv = FormValidation.formValidation(formValidation, {
                fields: {
                    title: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter title'
                            }
                        }
                    },
                    major_id: {
                        validators: {
                            notEmpty: {
                                message: 'Please select major'
                            }
                        }
                    },
                    course_id: {
                        validators: {
                            notEmpty: {
                                message: 'Please select course'
                            }
                        }
                    },
                    credit: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter credit',
                            },
                            numeric: {
                                message: 'The value must be a number'
                            }
                        }
                    },
                    year: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter year'
                            },
                            numeric: {
                                message: 'The value must be a number'
                            }
                        }
                    },
                    semester: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter semester',
                            },
                            numeric: {
                                message: 'The value must be a number'
                            }
                        }
                    },
                },
                plugins: {
                    trigger: new FormValidation.plugins.Trigger(),
                    bootstrap5: new FormValidation.plugins.Bootstrap5({
                        // Use this for enabling/changing valid/invalid class
                        // eleInvalidClass: '',
                        eleValidClass: '',
                        rowSelector: function(field, ele) {
                            // field is the field name & ele is the field element
                            switch (field) {
                                case 'title':
                                case 'major_id':
                                case 'course_id':
                                case 'credit':
                                case 'year':
                                case 'semester':
                                default:
                                    return '.row';
                            }
                        }
                    }),
                    submitButton: new FormValidation.plugins.SubmitButton(),
                    // Submit the form when all fields are valid
                    defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
                    autoFocus: new FormValidation.plugins.AutoFocus()
                },
                init: instance => {
                    instance.on('plugins.message.placed', function(e) {
                        //* Move the error message out of the `input-group` element
                        if (e.element.parentElement.classList.contains('input-group')) {
                            // `e.field`: The field name
                            // `e.messageElement`: The message element
                            // `e.element`: The field element
                            e.element.parentElement.insertAdjacentElement('afterend', e.messageElement);
                        }
                        //* Move the error message out of the `row` element for custom-options
                        if (e.element.parentElement.parentElement.classList.contains('custom-option')) {
                            e.element.closest('.row').insertAdjacentElement('afterend', e.messageElement);
                        }
                    });
                }
            });

            // Select2 (Major)
            if ($('#major_id').length) {
                $(this)
                    .on('change.select2', function () {
                        // Revalidate the color field when an option is chosen
                        fv.revalidateField('major_id');
                    });
            }

            // Select2 (Course)
            if ($('#course_id').length) {
                $(this)
                    .on('change.select2', function () {
                        // Revalidate the color field when an option is chosen
                        fv.revalidateField('course_id');
                    });
            }
        });
    </script>
@endsection

@section('content')
    <form id="majorCourseForm" action="{{ route('major-courses.store') }}" method="POST" autocomplete="off">
        @csrf
        <div class="d-flex flex-wrap justify-content-between align-items-center mb-3">
            <div class="d-flex flex-column justify-content-center">
                <h4 class="mb-1 mt-3">Add a new Major Course</h4>
                <p class="text-muted">Enter major course data</p>
            </div>
            <div class="d-flex align-content-center flex-wrap gap-3">
                <a href="{{ route('major-courses') }}" class="btn btn-label-secondary">Back</a>
                <button type="submit" class="btn btn-primary">Save</button>
            </div>
        </div>

        <div class="card">
            <div class="card-body">
                <div class="row g-3">
                    <div class="col-xxl-12 col-xl-12 col-lg-12 col-md-12 col-sm-12">
                        <label class="form-label" for="title">Title</label>
                        <input type="text" class="form-control" id="title" name="title" placeholder="Enter Title">
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="major_id">Major</label>
                        <select class="select2 form-select" name="major_id" id="major_id">
                            <option value="">Select Major</option>
                            @foreach($majors as $major)
                                <option value="{{ $major->id }}">{{ $major->title_en }}</option>
                            @endforeach
                        </select>
                    </div>
                    <div class="col-xxl-6 col-xl-6 col-lg-6 col-md-6 col-sm-12">
                        <label class="form-label" for="course_id">Course</label>
                        <select class="select2 form-select" name="course_id" id="course_id">
                            <option value="">Select Course</option>
                            @foreach($courses as $course)
                                <option value="{{ $course->id }}">{{ $course->title_en }}</option>
                            @endforeach
                        </select>
                    </div>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-4 col-sm-12">
                        <label class="form-label" for="credit">Credit</label>
                        <input type="text" class="form-control" id="credit" name="credit" placeholder="Enter Credit">
                    </div>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-4 col-sm-12">
                        <label class="form-label" for="year">Year</label>
                        <input type="text" class="form-control" id="year" name="year" placeholder="Enter Year">
                    </div>
                    <div class="col-xxl-4 col-xl-4 col-lg-4 col-md-4 col-sm-12">
                        <label class="form-label" for="semester">Semester</label>
                        <input type="text" class="form-control" id="semester" name="semester" placeholder="Enter Semester">
                    </div>
                    <div class="col-lg-12">
                        <label class="form-label" for="description">Description</label>
                        <textarea class="form-control" id="description" name="description" placeholder="Enter Description" cols="30" rows="14"></textarea>
                    </div>
                </div>
            </div>
        </div>
    </form>
@endsection
