@extends('layouts.contentNavbarLayoutBackend')

@section('title', 'Edit User')

@section('vendor-style')
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/flatpickr/flatpickr.css') }}">
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond-plugin-image-preview.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/filepond/css/filepond-plugin-file-poster.css') }}"/>
    <link rel="stylesheet" href="{{ asset('backend-assets/vendor/libs/@form-validation/form-validation.css') }}"/>
@endsection

@section('vendor-script')
    <script src="{{ asset('backend-assets/vendor/libs/flatpickr/flatpickr.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-image-preview.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-poster.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-validate-size.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/filepond/js/filepond-plugin-file-validate-type.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/popular.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/bootstrap5.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/@form-validation/auto-focus.js') }}"></script>
@endsection

@section('page-script')
    <script type="text/javascript">
        $(document).ready(function () {
            // Register the plugins
            FilePond.registerPlugin(
                FilePondPluginImagePreview,
                FilePondPluginFilePoster,
                FilePondPluginFileValidateSize,
                FilePondPluginFileValidateType
            );

            // Turn all file input elements into ponds
            FilePond.create(document.querySelector('input[name="image"]'), {
                imagePreviewHeight: 250,
                filePosterHeight: 250,
                allowMultiple: false,
                server: {
                    process: {
                        url: '/upload-temp',
                        method: 'POST',
                        headers: {
                            'X-CSRF-TOKEN': '{{ csrf_token() }}'
                        }
                    },
                    load: {
                        url: '{{ asset('uploads/avatars/' . $user->photo) }}',
                        method: 'GET',
                        headers: {
                            'X-CSRF-TOKEN': '{{ csrf_token() }}'
                        },
                        withCredentials: false,
                    },
                },
                files: [
                    @if ($user->photo)
                    {
                        source: '{{ asset('uploads/avatars/' . $user->photo) }}',
                        options: {
                            type: 'local',
                            file: {
                                name: '{{ $user->photo }}',
                                size: {{ filesize(public_path('uploads/avatars/' . $user->photo)) }},
                                type: 'image/{{ pathinfo($user->photo, PATHINFO_EXTENSION) }}'
                            },
                            metadata: {
                                poster: '{{ asset('uploads/avatars/' . $user->photo) }}'
                            }
                        }
                    }
                    @endif
                ]
            });

            $('#dob').flatpickr({
                dateFormat: "d-M-Y"
            });

            const formValidation = document.getElementById('userForm');
            FormValidation.formValidation(formValidation, {
                fields: {
                    first_name_en: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter first name in english'
                            }
                        }
                    },
                    last_name_en: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter last name in english'
                            }
                        }
                    },
                    email: {
                        validators: {
                            notEmpty: {
                                message: 'Please enter email'
                            }
                        }
                    },
                    sex: {
                        validators: {
                            notEmpty: {
                                message: 'Please select sex'
                            }
                        }
                    },
                    role: {
                        validators: {
                            notEmpty: {
                                message: 'Please select role'
                            }
                        }
                    },
                },
                plugins: {
                    trigger: new FormValidation.plugins.Trigger(),
                    bootstrap5: new FormValidation.plugins.Bootstrap5({
                        // Use this for enabling/changing valid/invalid class
                        // eleInvalidClass: '',
                        eleValidClass: '',
                        rowSelector: '.row'
                    }),
                    submitButton: new FormValidation.plugins.SubmitButton(),
                    // Submit the form when all fields are valid
                    defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
                    autoFocus: new FormValidation.plugins.AutoFocus()
                },
                init: instance => {
                    instance.on('plugins.message.placed', function(e) {
                        //* Move the error message out of the `input-group` element
                        if (e.element.parentElement.classList.contains('input-group')) {
                            // `e.field`: The field name
                            // `e.messageElement`: The message element
                            // `e.element`: The field element
                            e.element.parentElement.insertAdjacentElement('afterend', e.messageElement);
                        }
                        //* Move the error message out of the `row` element for custom-options
                        if (e.element.parentElement.parentElement.classList.contains('custom-option')) {
                            e.element.closest('.row').insertAdjacentElement('afterend', e.messageElement);
                        }
                    });
                }
            });
        });
    </script>
@endsection

@section('content')
    <form id="userForm" action="{{ route('user.update', $user->id) }}" method="POST" autocomplete="off" enctype="multipart/form-data">
        @csrf
        <div class="d-flex flex-wrap justify-content-between align-items-center mb-3">
            <div class="d-flex flex-column justify-content-center">
                <h4 class="mb-1 mt-3">Edit User</h4>
                <p class="text-muted">Enter user data</p>
            </div>
            <div class="d-flex align-content-center flex-wrap gap-3">
                <a href="{{ route('user') }}" class="btn btn-label-secondary">Back</a>
                <button type="submit" class="btn btn-primary">Save</button>
            </div>
        </div>

        <div class="card">
            <div class="card-body">
                <div class="row g-3">
                    <div class="col-lg-12">
                        <label class="form-label" for="image">Image</label>
                        <input type="file" class="filepond mb-0" id="image" name="image" data-max-file-size="3MB" data-max-files="1">
                    </div>
                    <div class="col-md-4">
                        <label for="first_name_en" class="form-label">First Name(En)</label>
                        <input class="form-control" type="text" id="first_name_en" name="first_name_en" value="{{ $user->first_name_en }}" placeholder="Enter First Name(En)" autofocus />
                    </div>
                    <div class="col-md-4">
                        <label for="middle_name_en" class="form-label">Middle Name(En)</label>
                        <input class="form-control" type="text" id="middle_name_en" name="middle_name_en" value="{{ $user->middle_name_en }}" placeholder="Enter Middle Name(En)" />
                    </div>
                    <div class="col-md-4">
                        <label for="last_name_en" class="form-label">Last Name(En)</label>
                        <input class="form-control" type="text" name="last_name_en" id="last_name_en" value="{{ $user->last_name_en }}" placeholder="Enter Last Name(En)" />
                    </div>
                    <div class="col-md-4">
                        <label for="first_name_kh" class="form-label">First Name(Kh)</label>
                        <input class="form-control" type="text" id="first_name_kh" name="first_name_kh" value="{{ $user->first_name_kh }}" placeholder="Enter First Name(Kh)" />
                    </div>
                    <div class="col-md-4">
                        <label for="middle_name_kh" class="form-label">Middle Name(Kh)</label>
                        <input class="form-control" type="text" id="middle_name_kh" name="middle_name_kh" value="{{ $user->middle_name_kh }}" placeholder="Enter Middle Name(Kh)" />
                    </div>
                    <div class="col-md-4">
                        <label for="last_name_kh" class="form-label">Last Name(Kh)</label>
                        <input class="form-control" type="text" name="last_name_kh" id="last_name_kh" value="{{ $user->last_name_kh }}" placeholder="Enter Last Name(Kh)" />
                    </div>
                    <div class="col-md-4">
                        <label for="email" class="form-label">E-mail</label>
                        <input class="form-control" type="text" id="email" name="email" value="{{ $user->email }}" placeholder="Enter Email" />
                    </div>
                    <div class="col-md-4">
                        <label for="sex" class="form-label">Sex</label>
                        <select name="sex" id="sex" class="form-select">
                            <option value="">Select Sex</option>
                            <option value="Male" {{ $user->sex === 'Male' ? 'selected' : '' }}>Male</option>
                            <option value="Female" {{ $user->sex === 'Female' ? 'selected' : '' }}>Female</option>
                        </select>
                    </div>
                    <div class="col-md-4">
                        <label for="dob" class="form-label">Date of Birth</label>
                        <input class="form-control" type="text" id="dob" name="dob" value="{{ date('d-M-Y', strtotime($user->dob)) }}" placeholder="DD-MMM-YYYY" />
                    </div>
                    <div class="col-md-4">
                        <label for="tel" class="form-label">Tel</label>
                        <input class="form-control" type="text" id="tel" name="tel" value="{{ $user->tel }}" placeholder="Enter Tel" />
                    </div>
                    <div class="col-md-4">
                        <label for="role" class="form-label">Role</label>
                        <select name="role" id="role" class="form-select">
                            <option value="">Select Role</option>
                            @foreach($roles as $role)
                                <option value="{{ $role->id }}" {{ $user->hasRole($role->name) ? 'selected' : '' }}>{{ $role->name }}</option>
                            @endforeach
                        </select>
                    </div>
                    <div class="col-md-6">
                        <label for="birth_place" class="form-label">Birth Place</label>
                        <input class="form-control" type="text" id="birth_place" name="birth_place" value="{{ $user->birth_place }}" placeholder="Enter Birth Place" />
                    </div>
                    <div class="col-md-6">
                        <label for="present_address" class="form-label">Present Address</label>
                        <input class="form-control" type="text" id="present_address" name="present_address" value="{{ $user->present_address }}" placeholder="Enter Present Address" />
                    </div>
                </div>
            </div>
        </div>
    </form>
@endsection
