@extends('layouts.contentNavbarLayoutFrontend')

@section('title', 'Faculty')

@section('page-style')
    <style>
        /* Target CKEditor instance */
        .ck-editor__editable_inline {
            border: none !important;  /* Remove the border */
            box-shadow: none !important;  /* Remove any shadow */
        }

        .ck.ck-editor__top .ck-sticky-panel .ck-sticky-panel__content {
            border: none !important;
        }
    </style>
@endsection

@section('vendor-script')
    <script src="{{ asset('backend-assets/vendor/libs/ckeditor5/ckeditor.min.js') }}"></script>
@endsection

@section('page-script')
    <script type="text/javascript">
        ClassicEditor
            .create(document.querySelector('#description'), {
                toolbar: [], // Remove toolbar
                isReadOnly: true,  // Use 'isReadOnly' instead of 'readOnly'
                image: {
                    toolbar: []  // Remove image toolbar if needed
                }
            })
            .then(editor => {
                editor.enableReadOnlyMode('description');  // Explicitly enforce read-only mode
            })
            .catch(error => {
                console.error('Error initializing CKEditor:', error);
            });
    </script>
@endsection

@section('content')
    <div class="pattern-square"></div>
    <!--Pageheader start-->
    <section class="py-5 py-lg-8">
        <div class="container">
            <div class="row">
                <div class="col-lg-12 col-md-12 col-12">
                    <div class="text-center">
                        <h1 class="mb-3">Faculty</h1>
                        <p class="mb-0">Faculty of UHST</p>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!--Pageheader end-->

    <!--Faculty start-->
    <section class="mb-xl-9">
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    <h1 class="mb-6">{{ $faculty->title_en }}</h1>
                </div>
            </div>

            <div class="row">
                <div class="col-lg-7 col-md-12">
                    <figure>
                        <img src="{{ !empty($faculty->image)  ? asset('uploads/faculty/' . $faculty->image) : asset('backend-assets/img/no-image/no-image.png') }}" width="350" class="img-fluid rounded-3 shadow-sm" alt="faculty" />
                    </figure>
                </div>
                <div class="col-lg-7 col-md-12 order-2">
                    <div class="mb-6 mt-4">
                        <div id="description">
                            {!! $faculty->description !!}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!--Faculty end-->

    <!--Institutes start-->
    <section class="mb-xl-9 my-5">
        <div class="container">
            <div class="row">
                <div class="col-lg-6">
                    <h3 class="mb-4">Institutes</h3>
                </div>
            </div>
            <div class="row g-5">
                @foreach($institutes as $institute)
                    <div class="col-lg-4 col-md-6">
                        <div class="card card-lift mb-5 mb-lg-0">
                            <div class="card-body p-lg-5">
                                <div class="mb-5">
                                    <div class="icon-lg icon-shape rounded-circle bg-warning bg-opacity-25 border border-warning border-opacity-10 border-4">
                                        <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-laptop-fill text-warning" viewBox="0 0 16 16">
                                            <path d="M2.5 2A1.5 1.5 0 0 0 1 3.5V12h14V3.5A1.5 1.5 0 0 0 13.5 2h-11zM0 12.5h16a1.5 1.5 0 0 1-1.5 1.5h-13A1.5 1.5 0 0 1 0 12.5z" />
                                        </svg>
                                    </div>
                                </div>
                                <div class="mb-4">
                                    <h4>{{ $institute->title_en }}</h4>
                                </div>

                                <a href="{{ route('institute', $institute->id) }}" class="icon-link icon-link-hover text-inherit stretched-link">
                                    See More
                                    <svg xmlns="http://www.w3.org/2000/svg" width="14" height="14" fill="currentColor" class="bi bi-arrow-right" viewBox="0 0 16 16">
                                        <path fill-rule="evenodd" d="M1 8a.5.5 0 0 1 .5-.5h11.793l-3.147-3.146a.5.5 0 0 1 .708-.708l4 4a.5.5 0 0 1 0 .708l-4 4a.5.5 0 0 1-.708-.708L13.293 8.5H1.5A.5.5 0 0 1 1 8z" />
                                    </svg>
                                </a>
                            </div>
                        </div>
                    </div>
                @endforeach
            </div>
        </div>
    </section>
    <!--Institutes end-->
@endsection
