@extends('layouts.contentNavbarLayoutFrontend')

@section('title', 'Publication Book Details')

@section('page-style')
    <style>
        /* Target CKEditor instance */
        .ck-editor__editable_inline {
            border: none !important;  /* Remove the border */
            box-shadow: none !important;  /* Remove any shadow */
        }

        .ck.ck-editor__top .ck-sticky-panel .ck-sticky-panel__content {
            border: none !important;
        }
    </style>
@endsection

@section('vendor-script')
    <script src="{{ asset('backend-assets/vendor/libs/ckeditor5/ckeditor.min.js') }}"></script>
@endsection

@section('page-script')
    <script type="text/javascript">
        ClassicEditor
            .create(document.querySelector('#description'), {
                toolbar: [], // Remove toolbar
                isReadOnly: true,  // Use 'isReadOnly' instead of 'readOnly'
                image: {
                    toolbar: []  // Remove image toolbar if needed
                }
            })
            .then(editor => {
                editor.enableReadOnlyMode('description');  // Explicitly enforce read-only mode
            })
            .catch(error => {
                console.error('Error initializing CKEditor:', error);
            });
    </script>
@endsection

@section('content')
    <div class="pattern-square"></div>
    <!--Back to page start-->
    <section class="py-5 py-lg-8">
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    <a href="{{ route('news') }}" class="text-reset icon-link icon-link-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-arrow-left" viewBox="0 0 16 16">
                            <path fill-rule="evenodd" d="M15 8a.5.5 0 0 0-.5-.5H2.707l3.147-3.146a.5.5 0 1 0-.708-.708l-4 4a.5.5 0 0 0 0 .708l4 4a.5.5 0 0 0 .708-.708L2.707 8.5H14.5A.5.5 0 0 0 15 8z" />
                        </svg>
                        back to Publication Books
                    </a>
                </div>
            </div>
        </div>
    </section>
    <!--Back to page end-->

    <!--Publication Book start-->
    <div class="mb-xl-9">
        <div class="container">
            <div class="row">
                <article class="col-lg-8 offset-lg-2">
                    <h1>{{ $publicationBook->title_en }}</h1>
                    <div class="d-flex align-items-center mt-lg-6 mt-4">
                        <div class="me-5">
                            <span class="fs-6">Author</span>
                            <div class="d-flex align-items-center mt-2">
                                <img src="{{ asset('backend-assets/img/avatars/19.jpg') }}" alt="Avatar" class="avatar avatar-xs rounded-circle" />
                                <div class="ms-2">
                                    <a href="#" class="text-reset fs-6">{{ $publicationBook->author }}</a>
                                </div>
                            </div>
                        </div>
                        <div class="me-5">
                            <span class="fs-6">Published date</span>
                            <div class="mt-2 text-dark">
                                <span class="fs-6">{{ date('M d, Y', strtotime($publicationBook->date_published)) }}</span>
                            </div>
                        </div>
                        <div class="me-5">
                            <span class="fs-6">Url</span>
                            <div class="mt-2">
                                <a href="{{ $publicationBook->url }}" class="small">Link Url</a>
                            </div>
                        </div>
                        <div>
                            <span class="fs-6">Doi</span>
                            <div class="mt-2">
                                <span class="fs-6">{{ !empty($publicationBook->doi) ? $publicationBook->doi : 'no doi available' }}</span>
                            </div>
                        </div>
                    </div>

                    <figure class="my-6" style="width: 300px">
                        <img src="{{ !empty($publicationBook->image)  ? asset('uploads/publication-book/' . $publicationBook->image) : asset('backend-assets/img/no-image/no-image.png') }}" alt="book" class="rounded-3 img-fluid w-100" style="width: 100%; height: 100%; object-fit: cover" />
                    </figure>
                    <div id="description">
                        {!! $publicationBook->description !!}
                    </div>
                </article>
            </div>
        </div>
    </div>
    <!--Publication Book end-->
@endsection
