@extends('layouts.contentNavbarLayoutFrontend')

@section('title', 'Training & Workshop Details')

@section('vendor-style')
    <link rel="stylesheet" href="{{ asset('frontend-assets/libs/glightbox/dist/css/glightbox.min.css') }}"/>
@endsection

@section('page-style')
    <style>
        /* Target CKEditor instance */
        .ck-editor__editable_inline {
            border: none !important;  /* Remove the border */
            box-shadow: none !important;  /* Remove any shadow */
        }

        .ck.ck-editor__top .ck-sticky-panel .ck-sticky-panel__content {
            border: none !important;
        }
    </style>
@endsection

@section('vendor-script')
    <script src="{{ asset('frontend-assets/libs/glightbox/dist/js/glightbox.min.js') }}"></script>
    <script src="{{ asset('frontend-assets/js/vendors/glight.js') }}"></script>
    <script src="{{ asset('backend-assets/vendor/libs/ckeditor5/ckeditor.min.js') }}"></script>
@endsection

@section('page-script')
    <script type="text/javascript">
        ClassicEditor
            .create(document.querySelector('#description'), {
                toolbar: [], // Remove toolbar
                isReadOnly: true,  // Use 'isReadOnly' instead of 'readOnly'
                image: {
                    toolbar: []  // Remove image toolbar if needed
                }
            })
            .then(editor => {
                editor.enableReadOnlyMode('description');  // Explicitly enforce read-only mode
            })
            .catch(error => {
                console.error('Error initializing CKEditor:', error);
            });
    </script>
@endsection

@section('content')
    <div class="pattern-square"></div>
    <!--Back to page start-->
    <section class="py-5 py-lg-8">
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    <a href="{{ route('training-workshop') }}" class="text-reset icon-link icon-link-hover">
                        <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-arrow-left" viewBox="0 0 16 16">
                            <path fill-rule="evenodd" d="M15 8a.5.5 0 0 0-.5-.5H2.707l3.147-3.146a.5.5 0 1 0-.708-.708l-4 4a.5.5 0 0 0 0 .708l4 4a.5.5 0 0 0 .708-.708L2.707 8.5H14.5A.5.5 0 0 0 15 8z" />
                        </svg>
                        back to training & workshop
                    </a>
                </div>
            </div>
        </div>
    </section>
    <!--Back to page end-->

    <!--Training & Workshop Details start-->
    <section class="py-5 py-lg-6">
        <div class="container">
            <div class="row">
                <div class="col-xl-10 offset-xl-1 col-md-12">
                    <h1>{{ $trainingWorkshop->title_en }}</h1>
                    <p>{{ $trainingWorkshop->sub_title_en }}</p>
                    <div class="d-flex align-items-center mt-lg-6 mt-4">
                        <div class="me-5">
                            <span class="fs-6">Start Date</span>
                            <div class="mt-2 text-dark">
                                <span class="fs-6">{{ date('M d, Y', strtotime($trainingWorkshop->start_date)) }}</span>
                            </div>
                        </div>
                        <div>
                            <span class="fs-6">End Date</span>
                            <div class="mt-2 text-dark">
                                <span class="fs-6">{{ date('M d, Y', strtotime($trainingWorkshop->end_date)) }}</span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="row mt-5">
                <div class="offset-xl-1 col-xl-10 col-md-12 col-12">
                    <div class="mb-md-7 mb-5">
                        <img src="{{ !empty($trainingWorkshop->image)  ? asset('uploads/training-workshop/' . $trainingWorkshop->image) : asset('backend-assets/img/no-image/no-image.png') }}" alt="integration" class="rounded-3 w-100" />
                    </div>

                    <div class="row gy-4">
                        @foreach($trainingWorkshopImages as $trainingWorkshopImage)
                            <div class="col-lg-4 col-md-4 col-12">
                                <a href="{{ asset('uploads/training-workshop/gallery/' . $trainingWorkshopImage->image) }}" class="glightbox rounded-3">
                                    <div class="rounded-3 card-lift" style="background-image: url({{ asset('uploads/training-workshop/gallery/' . $trainingWorkshopImage->image) }}); background-repeat: no-repeat; height: 350px; background-size: cover"></div>
                                </a>
                            </div>
                        @endforeach
                    </div>

                    <div id="description">
                        {!! $trainingWorkshop->description !!}
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!--Training & Workshop Details end-->
@endsection
