<?php

use App\Http\Controllers\Backend\AdminController;
use App\Http\Controllers\Backend\AdmissionController;
use App\Http\Controllers\Backend\CareerController;
use App\Http\Controllers\Backend\CkeditorController;
use App\Http\Controllers\Backend\ConferenceController;
use App\Http\Controllers\Backend\CourseController;
use App\Http\Controllers\Backend\DashboardController;
use App\Http\Controllers\Backend\FacultyController;
use App\Http\Controllers\Backend\HomeSlideController;
use App\Http\Controllers\Backend\InstituteController;
use App\Http\Controllers\Backend\FileUploadController;
use App\Http\Controllers\Backend\HistoryController;
use App\Http\Controllers\Backend\MajorController;
use App\Http\Controllers\Backend\MajorCourseController;
use App\Http\Controllers\Backend\MissionVisionController;
use App\Http\Controllers\Backend\NewsActivityController;
use App\Http\Controllers\Backend\PartnerController;
use App\Http\Controllers\Backend\PresidentMessageController;
use App\Http\Controllers\Backend\ProfileController;
use App\Http\Controllers\Backend\ProjectController;
use App\Http\Controllers\Backend\PublicationBookController;
use App\Http\Controllers\Backend\TrainingWorkshopController;
use App\Http\Controllers\Backend\ContactController;
use App\Http\Controllers\Backend\UserController;
use App\Http\Controllers\Backend\UserRoleController;
use Illuminate\Support\Facades\Route;

require __DIR__.'/auth.php';

/*=============== Backend Routes ===============*/
// Login
Route::get('/admin/login', [AdminController::class, 'create'])->name('admin.login');

Route::middleware(['auth', 'roles:admin'])->group(function () {
    // Dashboard
    Route::get('/admin/dashboard', [DashboardController::class, 'index'])->name('admin.dashboard');

    // Logout
    Route::get('/admin/logout', [AdminController::class, 'destroy'])->name('admin.logout');

    // Profile
    Route::controller(ProfileController::class)->group(function () {
        Route::get('/admin/profile/edit', 'edit')->name('admin.profile.edit');
        Route::post('/admin/profile/update', 'update')->name('admin.profile.update');
        Route::get('/admin/password/edit', 'editPassword')->name('admin.password.edit');
        Route::post('/admin/password/update', 'updatePassword')->name('admin.password.update');
    });

    // Upload Image with Ckeditor
    Route::post('/ckeditor/upload', [CkeditorController::class, 'store'])->name('ckeditor.upload');

    Route::controller(FileUploadController::class)->group(function () {
        // Upload Image into Temp with Filepond
        Route::post('/upload-temp', 'uploadTemp')->name('upload.temp');
        Route::post('/upload-multiple-temp', 'uploadMultipleTemp')->name('upload-multiple-temp');
        // Delete Image from Temp with Filepond
        Route::post('/delete-temp', 'deleteTemp')->name('delete-temp');
        Route::post('/delete-multiple-temp', 'deleteMultipleTemp')->name('delete-multiple-temp');
        Route::delete('/delete-project-image', 'deleteProjectImage')->name('delete-project-image');
        Route::delete('/delete-training-workshop-image', 'deleteTrainingWorkshopImage')->name('delete-training-workshop-image');
        Route::delete('/delete-conference-image', 'deleteConferenceImage')->name('delete-conference-image');
    });

    // Home Slide
    Route::controller(HomeSlideController::class)->group(function () {
        Route::get('/home-slides', 'index')->name('home-slides')->middleware(['permission:HomeSlide.List']);
        Route::get('/get-home-slides', 'getHomeSlides')->name('get-home-slides');
        Route::get('/home-slides/create', 'create')->name('home-slides.create')->middleware(['permission:HomeSlide.Create']);
        Route::post('/home-slides/store', 'store')->name('home-slides.store');
        Route::get('/home-slides/edit/{id}', 'edit')->name('home-slides.edit')->middleware(['permission:HomeSlide.Edit']);
        Route::post('/home-slides/update/{id}', 'update')->name('home-slides.update');
        Route::post('/home-slides/update-status', 'status')->name('home-slides.update-status');
        Route::get('/home-slides/delete', 'destroy')->name('home-slides.delete')->middleware(['permission:HomeSlide.Delete']);
    });

    // History
    Route::controller(HistoryController::class)->group(function () {
        Route::get('/about-us/histories', 'index')->name('about-us.histories')->middleware(['permission:History.List']);
        Route::get('/about-us/get-histories', 'getHistories')->name('about-us.get-histories');
        Route::get('/about-us/histories/create', 'create')->name('about-us.histories.create')->middleware(['permission:History.Create']);
        Route::post('/about-us/histories/store', 'store')->name('about-us.histories.store');
        Route::get('/about-us/histories/edit/{id}', 'edit')->name('about-us.histories.edit')->middleware(['permission:History.Edit']);
        Route::post('/about-us/histories/update/{id}', 'update')->name('about-us.histories.update');
        Route::post('/about-us/histories/update-status', 'status')->name('about-us.histories.update-status');
        Route::get('/about-us/histories/delete', 'destroy')->name('about-us.histories.delete')->middleware(['permission:History.Delete']);
    });

    // Mission & Vision
    Route::controller(MissionVisionController::class)->group(function () {
        Route::get('/about-us/mission-visions', 'index')->name('about-us.mission-visions')->middleware(['permission:MissionVision.List']);
        Route::get('/about-us/get-mission-visions', 'getMissionVisions')->name('about-us.get-mission-visions');
        Route::get('/about-us/mission-visions/create', 'create')->name('about-us.mission-visions.create')->middleware(['permission:MissionVision.Create']);
        Route::post('/about-us/mission-visions/store', 'store')->name('about-us.mission-visions.store');
        Route::get('/about-us/mission-visions/edit/{id}', 'edit')->name('about-us.mission-visions.edit')->middleware(['permission:MissionVision.Edit']);
        Route::post('/about-us/mission-visions/update/{id}', 'update')->name('about-us.mission-visions.update');
        Route::post('/about-us/mission-visions/update-status', 'status')->name('about-us.mission-visions.update-status');
        Route::get('/about-us/mission-visions/delete', 'destroy')->name('about-us.mission-visions.delete')->middleware(['permission:MissionVision.Delete']);
    });

    // President Message
    Route::controller(PresidentMessageController::class)->group(function () {
        Route::get('/about-us/president-messages', 'index')->name('about-us.president-messages');
        Route::get('/about-us/get-president-messages', 'getPresidentMessages')->name('about-us.get-president-messages')->middleware(['permission:PresidentMessage.List']);
        Route::get('/about-us/president-messages/create', 'create')->name('about-us.president-messages.create')->middleware(['permission:PresidentMessage.Create']);
        Route::post('/about-us/president-messages/store', 'store')->name('about-us.president-messages.store');
        Route::get('/about-us/president-messages/edit/{id}', 'edit')->name('about-us.president-messages.edit')->middleware(['permission:PresidentMessage.Edit']);
        Route::post('/about-us/president-messages/update/{id}', 'update')->name('about-us.president-messages.update');
        Route::post('/about-us/president-messages/update-status', 'status')->name('about-us.president-messages.update-status');
        Route::get('/about-us/president-messages/delete/{id}', 'destroy')->name('about-us.president-messages.delete')->middleware(['permission:PresidentMessage.Delete']);
    });

    // Partner
    Route::controller(PartnerController::class)->group(function () {
        Route::get('/about-us/partners', 'index')->name('about-us.partners')->middleware(['permission:Partner.List']);
        Route::get('/about-us/get-partners', 'getPartners')->name('about-us.get-partners');
        Route::get('/about-us/partners/create', 'create')->name('about-us.partners.create')->middleware(['permission:Partner.Create']);
        Route::post('/about-us/partners/store', 'store')->name('about-us.partners.store');
        Route::get('/about-us/partners/edit/{id}', 'edit')->name('about-us.partners.edit')->middleware(['permission:Partner.Edit']);
        Route::post('/about-us/partners/update/{id}', 'update')->name('about-us.partners.update');
        Route::post('/about-us/partners/update-status', 'status')->name('about-us.partners.update-status');
        Route::get('/about-us/partners/delete/{id}', 'destroy')->name('about-us.partners.delete')->middleware(['permission:Partner.Delete']);
    });

    // Faculties
    Route::controller(FacultyController::class)->group(function () {
        Route::get('/faculties', 'index')->name('faculties')->middleware(['permission:Faculty.List']);
        Route::get('/faculties/get-faculties', 'getFaculties')->name('faculties.get-faculties');
        Route::get('/faculties/create', 'create')->name('faculties.create')->middleware(['permission:Faculty.Create']);
        Route::post('/faculties/store', 'store')->name('faculties.store');
        Route::get('/faculties/edit/{id}', 'edit')->name('faculties.edit')->middleware(['permission:Faculty.Edit']);
        Route::post('/faculties/update/{id}', 'update')->name('faculties.update');
        Route::post('/faculties/update-status', 'status')->name('faculties.update-status');
        Route::get('/faculties/delete', 'destroy')->name('faculties.delete')->middleware(['permission:Faculty.Delete']);
    });

    // Institute
    Route::controller(InstituteController::class)->group(function () {
        Route::get('/institutes', [InstituteController::class, 'index'])->name('institutes')->middleware(['permission:Institute.List']);
        Route::get('/institutes/get-institutes', 'getInstitutes')->name('faculties.get-institutes');
        Route::get('/institutes/create', 'create')->name('institutes.create')->middleware(['permission:Institute.Create']);
        Route::post('/institutes/store', 'store')->name('institutes.store');
        Route::get('/institutes/edit/{id}', 'edit')->name('institutes.edit')->middleware(['permission:Institute.Edit']);
        Route::post('/institutes/update/{id}', 'update')->name('institutes.update');
        Route::post('/institutes/update-status', 'status')->name('institutes.update-status');
        Route::get('/institutes/delete', 'destroy')->name('institutes.delete')->middleware(['permission:Institute.Delete']);
    });

    // Admission
    Route::controller(AdmissionController::class)->group(function () {
        Route::get('/study/admissions', 'index')->name('study.admissions')->middleware(['permission:Admission.List']);
        Route::get('/study/get-admissions', 'getAdmissions')->name('study.get-admissions');
        Route::get('/study/admissions/create', 'create')->name('study.admissions.create')->middleware(['permission:Admission.Create']);
        Route::post('/study/admissions/store', 'store')->name('study.admissions.store');
        Route::get('/study/admissions/edit/{id}', 'edit')->name('study.admissions.edit')->middleware(['permission:Admission.Edit']);
        Route::post('/study/admissions/update/{id}', 'update')->name('study.admissions.update');
        Route::post('/study/admissions/update-status', 'status')->name('study.admissions.update-status');
        Route::get('/study/admissions/delete', 'destroy')->name('study.admissions.delete')->middleware(['permission:Admission.Delete']);
    });

    // Project
    Route::controller(ProjectController::class)->group(function () {
        Route::get('/research-innovation/projects', 'index')->name('research-innovation.projects')->middleware(['permission:Project.List']);
        Route::get('/research-innovation/get-projects', 'getProjects')->name('research-innovation.get-projects');
        Route::get('/research-innovation/projects/create', 'create')->name('research-innovation.projects.create')->middleware(['permission:Project.Create']);
        Route::post('/research-innovation/projects/store', 'store')->name('research-innovation.projects.store');
        Route::get('/research-innovation/projects/edit/{id}', 'edit')->name('research-innovation.projects.edit')->middleware(['permission:Project.Edit']);
        Route::post('/research-innovation/projects/update/{id}', 'update')->name('research-innovation.projects.update');
        Route::post('/research-innovation/projects/update-status', 'status')->name('research-innovation.projects.update-status');
        Route::get('/research-innovation/projects/delete', 'destroy')->name('research-innovation.projects.delete')->middleware(['permission:Project.Delete']);

    });

    // Publication Book
    Route::controller(PublicationBookController::class)->group(function () {
        Route::get('/research-innovation/publication-books', 'index')->name('research-innovation.publication-books')->middleware(['permission:PublicationBook.List']);
        Route::get('/research-innovation/get-publication-books', 'getPublicationBooks')->name('research-innovation.get-publication-books');
        Route::get('/research-innovation/publication-books/create', 'create')->name('research-innovation.publication-books.create')->middleware(['permission:PublicationBook.Create']);
        Route::post('/research-innovation/publication-books/store', 'store')->name('research-innovation.publication-books.store');
        Route::get('/research-innovation/publication-books/edit/{id}', 'edit')->name('research-innovation.publication-books.edit')->middleware(['permission:PublicationBook.Edit']);
        Route::post('/research-innovation/publication-books/update/{id}', 'update')->name('research-innovation.publication-books.update');
        Route::post('/research-innovation/publication-books/update-status', 'status')->name('research-innovation.publication-books.update-status');
        Route::get('/research-innovation/publication-books/delete', 'destroy')->name('research-innovation.publication-books.delete')->middleware(['permission:PublicationBook.Delete']);
    });

    // Training & Workshop
    Route::controller(TrainingWorkshopController::class)->group(function () {
        Route::get('/research-innovation/training-workshops', 'index')->name('research-innovation.training-workshops')->middleware(['permission:TrainingWorkshop.List']);
        Route::get('/research-innovation/get-training-workshops', 'getTrainingWorkshops')->name('research-innovation.get-training-workshops');
        Route::get('/research-innovation/training-workshops/create', 'create')->name('research-innovation.training-workshops.create')->middleware(['permission:TrainingWorkshop.Create']);
        Route::post('/research-innovation/training-workshops/store', 'store')->name('research-innovation.training-workshops.store');
        Route::get('/research-innovation/training-workshops/edit/{id}', 'edit')->name('research-innovation.training-workshops.edit')->middleware(['permission:TrainingWorkshop.Edit']);
        Route::post('/research-innovation/training-workshops/update/{id}', 'update')->name('research-innovation.training-workshops.update');
        Route::post('/research-innovation/training-workshops/update-status', 'status')->name('research-innovation.training-workshops.update-status');
        Route::get('/research-innovation/training-workshops/delete', 'destroy')->name('research-innovation.training-workshops.delete')->middleware(['permission:TrainingWorkshop.Delete']);
    });

    // Conference
    Route::controller(ConferenceController::class)->group(function () {
        Route::get('/research-innovation/conferences', 'index')->name('research-innovation.conferences')->middleware(['permission:Conference.List']);
        Route::get('/research-innovation/get-conferences', 'getConferences')->name('research-innovation.get-conferences');
        Route::get('/research-innovation/conferences/create', 'create')->name('research-innovation.conferences.create')->middleware(['permission:Conference.Create']);
        Route::post('/research-innovation/conferences/store', 'store')->name('research-innovation.conferences.store');
        Route::get('/research-innovation/conferences/edit/{id}', 'edit')->name('research-innovation.conferences.edit')->middleware(['permission:Conference.Edit']);
        Route::post('/research-innovation/conferences/update/{id}', 'update')->name('research-innovation.conferences.update');
        Route::post('/research-innovation/conferences/update-status', 'status')->name('research-innovation.conferences.update-status');
        Route::get('/research-innovation/conferences/delete', 'destroy')->name('research-innovation.conferences.delete')->middleware(['permission:Conference.Delete']);
    });

    // Contact
    Route::controller(ContactController::class)->group(function () {
        Route::get('/contacts', 'index')->name('contacts')->middleware(['permission:ContactLocation.List']);
        Route::get('/get-contacts', 'getContacts')->name('get-contacts');
        Route::get('/contacts/create', 'create')->name('contacts.create')->middleware(['permission:ContactLocation.Create']);
        Route::post('/contacts/store', 'store')->name('contacts.store');
        Route::get('/contacts/edit/{id}', 'edit')->name('contacts.edit')->middleware(['permission:ContactLocation.Edit']);
        Route::post('/contacts/update/{id}', 'update')->name('contacts.update');
        Route::post('/contacts/update-status', 'status')->name('contacts.update-status');
        Route::get('/contacts/delete', 'destroy')->name('contacts.delete')->middleware(['permission:ContactLocation.Delete']);
    });

    // News & Activity
    Route::controller(NewsActivityController::class)->group(function () {
        Route::get('/news-activities', 'index')->name('news-activities')->middleware(['permission:NewsActivities.List']);
        Route::get('/get-news-activities', 'getNewsActivities')->name('get-news-activities');
        Route::get('/news-activities/create', 'create')->name('news-activities.create')->middleware(['permission:NewsActivities.Create']);
        Route::post('/news-activities/store', 'store')->name('news-activities.store');
        Route::get('/news-activities/edit/{id}', 'edit')->name('news-activities.edit')->middleware(['permission:NewsActivities.Edit']);
        Route::post('/news-activities/update/{id}', 'update')->name('news-activities.update');
        Route::post('/news-activities/update-status', 'status')->name('news-activities.update-status');
        Route::get('/news-activities/delete', 'destroy')->name('news-activities.delete')->middleware(['permission:NewsActivities.Delete']);
    });

    // Career
    Route::controller(CareerController::class)->group(function () {
        Route::get('/careers', 'index')->name('careers')->middleware(['permission:Career.List']);
        Route::get('/get-careers', 'getCareers')->name('get-careers');
        Route::get('/careers/create', 'create')->name('careers.create')->middleware(['permission:Career.Create']);
        Route::post('/careers/store', 'store')->name('careers.store');
        Route::get('/careers/edit/{id}', 'edit')->name('careers.edit')->middleware(['permission:Career.Edit']);
        Route::post('/careers/update/{id}', 'update')->name('careers.update');
        Route::post('/careers/update-status', 'status')->name('careers.update-status');
        Route::get('/careers/delete', 'destroy')->name('careers.delete')->middleware(['permission:Career.Delete']);
    });

    // Major Course
    Route::controller(MajorCourseController::class)->group(function () {
        Route::get('/major-courses', 'index')->name('major-courses')->middleware(['permission:MajorCourse.List']);
        Route::get('/get-major-courses', 'getMajorCourses')->name('get-major-courses');
        Route::get('/major-courses/create', 'create')->name('major-courses.create')->middleware(['permission:MajorCourse.Create']);
        Route::post('/major-courses/store', 'store')->name('major-courses.store');
        Route::get('/major-courses/edit/{id}', 'edit')->name('major-courses.edit')->middleware(['permission:MajorCourse.Edit']);
        Route::post('/major-courses/update/{id}', 'update')->name('major-courses.update');
        Route::post('/major-courses/update-status', 'status')->name('major-courses.update-status');
        Route::get('/major-courses/delete', 'destroy')->name('major-courses.delete')->middleware(['permission:MajorCourse.Delete']);
    });

    // Major
    Route::controller(MajorController::class)->group(function () {
        Route::get('/major-course/majors', 'index')->name('major-course.majors')->middleware(['permission:Major.List']);
        Route::get('/major-course/get-majors', 'getMajors')->name('major-course.get-majors');
        Route::get('/major-course/majors/create', 'create')->name('major-course.majors.create')->middleware(['permission:Major.Create']);
        Route::post('/major-course/majors/store', 'store')->name('major-course.majors.store');
        Route::get('/major-course/majors/edit/{id}', 'edit')->name('major-course.majors.edit')->middleware(['permission:Major.Edit']);
        Route::post('/major-course/majors/update/{id}', 'update')->name('major-course.majors.update');
        Route::post('/major-course/majors/update-status', 'status')->name('major-course.majors.update-status');
        Route::get('/major-course/majors/delete', 'destroy')->name('major-course.majors.delete')->middleware(['permission:Major.Delete']);
    });

    // Course
    Route::controller(CourseController::class)->group(function () {
        Route::get('/major-course/courses', 'index')->name('major-course.courses')->middleware(['permission:Course.List']);
        Route::get('/major-course/get-courses', 'getCourse')->name('major-course.get-courses');
        Route::get('/major-course/courses/create', 'create')->name('major-course.courses.create')->middleware(['permission:Course.Create']);
        Route::post('/major-course/courses/store', 'store')->name('major-course.courses.store');
        Route::get('/major-course/courses/edit/{id}', 'edit')->name('major-course.courses.edit')->middleware(['permission:Course.Edit']);
        Route::post('/major-course/courses/update/{id}', 'update')->name('major-course.courses.update');
        Route::post('/major-course/courses/update-status', 'status')->name('major-course.courses.update-status');
        Route::get('/major-course/courses/delete', 'destroy')->name('major-course.courses.delete')->middleware(['permission:Course.Delete']);
    });

    // User
    Route::controller(UserController::class)->group(function () {
        Route::get('/user', 'index')->name('user')->middleware(['permission:User.List']);
        Route::get('/get-users', 'getUsers')->name('get-users');
        Route::get('/user/create', 'create')->name('user.create')->middleware(['permission:User.Create']);
        Route::post('/user/store', 'store')->name('user.store');
        Route::get('/user/edit/{id}', 'edit')->name('user.edit')->middleware(['permission:User.Edit']);
        Route::post('/user/update/{id}', 'update')->name('user.update');
        Route::post('/user/update-status', 'status')->name('user.update-status');
        Route::get('/user/delete/{id}', 'destroy')->name('user.delete')->middleware(['permission:User.Delete']);
    });

    // User Role
    Route::controller(UserRoleController::class)->group(function () {
        Route::get('/user/role', 'index')->name('user.role')->middleware(['permission:UserRole.List']);
        Route::get('/get-user-roles', 'getUserRoles')->name('get-user-roles');
        Route::get('/user/role/create', 'create')->name('user.role.create')->middleware(['permission:UserRole.Create']);
        Route::post('/user/role/store', 'store')->name('user.role.store');
        Route::get('/user/role/edit/{id}', 'edit')->name('user.role.edit')->middleware(['permission:UserRole.Edit']);
        Route::post('/user/role/update/{id}', 'update')->name('user.role.update');
        Route::get('/user/role/delete/{id}', 'destroy')->name('user.role.delete')->middleware(['permission:UserRole.Delete']);
    });
});


/*=============== Frontend Routes ===============*/
// Home
Route::controller(\App\Http\Controllers\Frontend\HomeController::class)->group(function () {
    Route::get('/', 'index');
    Route::get('/home', 'index')->name('home');
    Route::get('/home/details/{id}', 'show')->name('home.details');
});

// History
Route::get('/about-us/history', [\App\Http\Controllers\Frontend\HistoryController::class, 'index'])->name('history');

// Mission Vision
Route::get('/about-us/mission-vision', [\App\Http\Controllers\Frontend\MissionVisionController::class, 'index'])->name('mission-vision');

// President Message
Route::get('/about-us/president-message', [\App\Http\Controllers\Frontend\PresidentMessageController::class, 'index'])->name('president-message');

// Partner
Route::controller(\App\Http\Controllers\Frontend\PartnerController::class)->group(function () {
    Route::get('/about-us/partner', 'index')->name('partner');
    Route::get('/about-us/partner/details/{id}', 'show')->name('partner.details');
});

// Faculty
Route::get('/faculty/{id}', [\App\Http\Controllers\Frontend\FacultyController::class, 'index'])->name('faculty');

// Institute
Route::get('/institute/{id}', [\App\Http\Controllers\Frontend\InstituteController::class, 'index'])->name('institute');

// Major & Course
Route::controller(\App\Http\Controllers\Frontend\MajorCourseController::class)->group(function () {
    Route::get('/major-course/{id}', 'index')->name('major-course');
    Route::get('/major-course/details/{id}', 'show')->name('major-course.details');
});

// Admission
Route::get('/study/admission', [\App\Http\Controllers\Frontend\AdmissionController::class, 'index'])->name('admission');

// Project
Route::controller(\App\Http\Controllers\Frontend\ProjectController::class)->group(function () {
    Route::get('/research-innovation/project', 'index')->name('project');
    Route::get('/research-innovation/project/details/{id}', 'show')->name('project.details');
});

// Publication Book
Route::controller(\App\Http\Controllers\Frontend\PublicationBookController::class)->group(function () {
    Route::get('/research-innovation/publication-book', 'index')->name('publication-book');
    Route::get('/research-innovation/publication-book/details/{id}', 'show')->name('publication-book.details');
});

// Training & Workshop
Route::controller(\App\Http\Controllers\Frontend\TrainingWorkshopController::class)->group(function () {
    Route::get('/research-innovation/training-workshop', 'index')->name('training-workshop');
    Route::get('/research-innovation/training-workshop/details/{id}', 'show')->name('training-workshop.details');
});

// Conference
Route::controller(\App\Http\Controllers\Frontend\ConferenceController::class)->group(function () {
    Route::get('/research-innovation/conference', 'index')->name('conference');
    Route::get('/research-innovation/conference/details/{id}', 'show')->name('conference.details');
});

// Contact
Route::get('/contact', [\App\Http\Controllers\Frontend\ContactController::class, 'index'])->name('contact');

// News
Route::controller(\App\Http\Controllers\Frontend\NewsController::class)->group(function () {
    Route::get('/news', 'index')->name('news');
    Route::get('/news/details/{id}', 'show')->name('news.details');
});

// Career
Route::controller(\App\Http\Controllers\Frontend\CareerController::class)->group(function () {
    Route::get('/career', 'index')->name('career');
    Route::get('/career/details/{id}', 'show')->name('career.details');
});
